@@ -1,4 +1,4 @@
-# Copyright 2012-2013, Damian Johnson and The Tor Project
+# Copyright 2012-2014, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 import datetime
@@ -18,8 +18,9 @@ from stem.util import connection, log, str_tools, tor_tools
 # because some positional arguments, like circuit paths, can have an equal
 # sign.
 
-KW_ARG = re.compile("^(.*) ([A-Za-z0-9_]+)=(\S*)$")
-QUOTED_KW_ARG = re.compile("^(.*) ([A-Za-z0-9_]+)=\"(.*)\"$")
+KW_ARG = re.compile('^(.*) ([A-Za-z0-9_]+)=(\S*)$')
+QUOTED_KW_ARG = re.compile('^(.*) ([A-Za-z0-9_]+)="(.*)"$')
+CELL_TYPE = re.compile('^[a-z0-9_]+$')
 
 
 class Event(stem.response.ControlMessage):
@@ -46,7 +47,7 @@ class Event(stem.response.ControlMessage):
       arrived_at = int(time.time())
 
     if not str(self).strip():
-      raise stem.ProtocolError("Received a blank tor event. Events must at the very least have a type.")
+      raise stem.ProtocolError('Received a blank tor event. Events must at the very least have a type.')
 
     self.type = str(self).split().pop(0)
     self.arrived_at = arrived_at
@@ -116,7 +117,7 @@ class Event(stem.response.ControlMessage):
             if attr_values[-1].endswith('"'):
               break
 
-          attr_value = " ".join(attr_values)[1:-1]
+          attr_value = ' '.join(attr_values)[1:-1]
         else:
           attr_value = positional.pop(0)
 
@@ -146,7 +147,7 @@ class Event(stem.response.ControlMessage):
 
       for value in attr_values:
         if not value in attr_enum:
-          log_id = "event.%s.unknown_%s.%s" % (self.type.lower(), attr, value)
+          log_id = 'event.%s.unknown_%s.%s' % (self.type.lower(), attr, value)
           unrecognized_msg = "%s event had an unrecognized %s (%s). Maybe a new addition to the control protocol? Full Event: '%s'" % (self.type, attr, value, self)
           log.log_once(log_id, log.INFO, unrecognized_msg)
 
@@ -158,6 +159,9 @@ class AddrMapEvent(Event):
   The ADDRMAP event was one of the first Control Protocol V1 events and was
   introduced in tor version 0.1.1.1-alpha.
 
+  .. versionchanged:: 1.1.0
+     Added the cached attribute.
+
   :var str hostname: address being resolved
   :var str destination: destionation of the resolution, this is usually an ip,
     but could be a hostname if TrackHostExits is enabled or **NONE** if the
@@ -169,34 +173,34 @@ class AddrMapEvent(Event):
     **False** otherwise or **None** if undefined
   """
 
-  _POSITIONAL_ARGS = ("hostname", "destination", "expiry")
+  _POSITIONAL_ARGS = ('hostname', 'destination', 'expiry')
   _KEYWORD_ARGS = {
-    "error": "error",
-    "EXPIRES": "utc_expiry",
-    "CACHED": "cached",
+    'error': 'error',
+    'EXPIRES': 'utc_expiry',
+    'CACHED': 'cached',
   }
-  _OPTIONALLY_QUOTED = ("expiry")
+  _OPTIONALLY_QUOTED = ('expiry')
 
   def _parse(self):
-    if self.destination == "<error>":
+    if self.destination == '<error>':
       self.destination = None
 
     if self.expiry is not None:
-      if self.expiry == "NEVER":
+      if self.expiry == 'NEVER':
         self.expiry = None
       else:
         try:
-          self.expiry = datetime.datetime.strptime(self.expiry, "%Y-%m-%d %H:%M:%S")
+          self.expiry = datetime.datetime.strptime(self.expiry, '%Y-%m-%d %H:%M:%S')
         except ValueError:
-          raise stem.ProtocolError("Unable to parse date in ADDRMAP event: %s" % self)
+          raise stem.ProtocolError('Unable to parse date in ADDRMAP event: %s' % self)
 
     if self.utc_expiry is not None:
-      self.utc_expiry = datetime.datetime.strptime(self.utc_expiry, "%Y-%m-%d %H:%M:%S")
+      self.utc_expiry = datetime.datetime.strptime(self.utc_expiry, '%Y-%m-%d %H:%M:%S')
 
     if self.cached is not None:
-      if self.cached == "YES":
+      if self.cached == 'YES':
         self.cached = True
-      elif self.cached == "NO":
+      elif self.cached == 'NO':
         self.cached = False
       else:
         raise stem.ProtocolError("An ADDRMAP event's CACHED mapping can only be 'YES' or 'NO': %s" % self)
@@ -223,7 +227,7 @@ class AuthDirNewDescEvent(Event):
 
     if len(lines) < 5:
       raise stem.ProtocolError("AUTHDIR_NEWDESCS events must contain lines for at least the type, action, message, descriptor, and terminating 'OK'")
-    elif not lines[-1] == "OK":
+    elif not lines[-1] == 'OK':
       raise stem.ProtocolError("AUTHDIR_NEWDESCS doesn't end with an 'OK'")
 
     self.action = lines[1]
@@ -242,13 +246,13 @@ class BandwidthEvent(Event):
   :var long written: bytes sent by tor that second
   """
 
-  _POSITIONAL_ARGS = ("read", "written")
+  _POSITIONAL_ARGS = ('read', 'written')
 
   def _parse(self):
     if not self.read:
-      raise stem.ProtocolError("BW event is missing its read value")
+      raise stem.ProtocolError('BW event is missing its read value')
     elif not self.written:
-      raise stem.ProtocolError("BW event is missing its written value")
+      raise stem.ProtocolError('BW event is missing its written value')
     elif not self.read.isdigit() or not self.written.isdigit():
       raise stem.ProtocolError("A BW event's bytes sent and received should be a positive numeric value, received: %s" % self)
 
@@ -274,16 +278,16 @@ class BuildTimeoutSetEvent(Event):
   :var float close_rate: ratio of measurement circuits that are closed
   """
 
-  _POSITIONAL_ARGS = ("set_type",)
+  _POSITIONAL_ARGS = ('set_type',)
   _KEYWORD_ARGS = {
-    "TOTAL_TIMES": "total_times",
-    "TIMEOUT_MS": "timeout",
-    "XM": "xm",
-    "ALPHA": "alpha",
-    "CUTOFF_QUANTILE": "quantile",
-    "TIMEOUT_RATE": "timeout_rate",
-    "CLOSE_MS": "close_timeout",
-    "CLOSE_RATE": "close_rate",
+    'TOTAL_TIMES': 'total_times',
+    'TIMEOUT_MS': 'timeout',
+    'XM': 'xm',
+    'ALPHA': 'alpha',
+    'CUTOFF_QUANTILE': 'quantile',
+    'TIMEOUT_RATE': 'timeout_rate',
+    'CLOSE_MS': 'close_timeout',
+    'CLOSE_RATE': 'close_rate',
   }
   _VERSION_ADDED = stem.version.Requirement.EVENT_BUILDTIMEOUT_SET
 
@@ -297,7 +301,7 @@ class BuildTimeoutSetEvent(Event):
         try:
           setattr(self, param, int(param_value))
         except ValueError:
-          raise stem.ProtocolError("The %s of a BUILDTIMEOUT_SET should be an integer: %s" % (param, self))
+          raise stem.ProtocolError('The %s of a BUILDTIMEOUT_SET should be an integer: %s' % (param, self))
 
     for param in ('alpha', 'quantile', 'timeout_rate', 'close_rate'):
       param_value = getattr(self, param)
@@ -306,7 +310,7 @@ class BuildTimeoutSetEvent(Event):
         try:
           setattr(self, param, float(param_value))
         except ValueError:
-          raise stem.ProtocolError("The %s of a BUILDTIMEOUT_SET should be a float: %s" % (param, self))
+          raise stem.ProtocolError('The %s of a BUILDTIMEOUT_SET should be a float: %s' % (param, self))
 
     self._log_if_unrecognized('set_type', stem.TimeoutSetType)
 
@@ -336,15 +340,15 @@ class CircuitEvent(Event):
   :var stem.CircClosureReason remote_reason: remote side's reason for the circuit to be closed
   """
 
-  _POSITIONAL_ARGS = ("id", "status", "path")
+  _POSITIONAL_ARGS = ('id', 'status', 'path')
   _KEYWORD_ARGS = {
-    "BUILD_FLAGS": "build_flags",
-    "PURPOSE": "purpose",
-    "HS_STATE": "hs_state",
-    "REND_QUERY": "rend_query",
-    "TIME_CREATED": "created",
-    "REASON": "reason",
-    "REMOTE_REASON": "remote_reason",
+    'BUILD_FLAGS': 'build_flags',
+    'PURPOSE': 'purpose',
+    'HS_STATE': 'hs_state',
+    'REND_QUERY': 'rend_query',
+    'TIME_CREATED': 'created',
+    'REASON': 'reason',
+    'REMOTE_REASON': 'remote_reason',
   }
 
   def _parse(self):
@@ -357,7 +361,7 @@ class CircuitEvent(Event):
       try:
         self.created = str_tools._parse_iso_timestamp(self.created)
       except ValueError as exc:
-        raise stem.ProtocolError("Unable to parse create date (%s): %s" % (exc, self))
+        raise stem.ProtocolError('Unable to parse create date (%s): %s' % (exc, self))
 
     if not tor_tools.is_valid_circuit_id(self.id):
       raise stem.ProtocolError("Circuit IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
@@ -369,6 +373,43 @@ class CircuitEvent(Event):
     self._log_if_unrecognized('reason', stem.CircClosureReason)
     self._log_if_unrecognized('remote_reason', stem.CircClosureReason)
 
+  def _compare(self, other, method):
+    if not isinstance(other, CircuitEvent):
+      return False
+
+    for attr in ('id', 'status', 'path', 'build_flags', 'purpose', 'hs_state', 'rend_query', 'created', 'reason', 'remote_reason'):
+      my_attr = getattr(self, attr)
+      other_attr = getattr(other, attr)
+
+      # Our id attribute is technically a string, but Tor conventionally uses
+      # ints. Attempt to handle as ints if that's the case so we get numeric
+      # ordering.
+
+      if attr == 'id' and my_attr and other_attr:
+        if my_attr.isdigit() and other_attr.isdigit():
+          my_attr = int(my_attr)
+          other_attr = int(other_attr)
+
+      if my_attr is None:
+        my_attr = ''
+
+      if other_attr is None:
+        other_attr = ''
+
+      if my_attr != other_attr:
+        return method(my_attr, other_attr)
+
+    return True
+
+  def __eq__(self, other):
+    return self._compare(other, lambda s, o: s == o)
+
+  def __gt__(self, other):
+    return self._compare(other, lambda s, o: s > o)
+
+  def __ge__(self, other):
+    return self._compare(other, lambda s, o: s >= o)
+
 
 class CircMinorEvent(Event):
   """
@@ -391,15 +432,15 @@ class CircMinorEvent(Event):
   :var stem.HiddenServiceState old_hs_state: prior status as a hidden service circuit
   """
 
-  _POSITIONAL_ARGS = ("id", "event", "path")
+  _POSITIONAL_ARGS = ('id', 'event', 'path')
   _KEYWORD_ARGS = {
-    "BUILD_FLAGS": "build_flags",
-    "PURPOSE": "purpose",
-    "HS_STATE": "hs_state",
-    "REND_QUERY": "rend_query",
-    "TIME_CREATED": "created",
-    "OLD_PURPOSE": "old_purpose",
-    "OLD_HS_STATE": "old_hs_state",
+    'BUILD_FLAGS': 'build_flags',
+    'PURPOSE': 'purpose',
+    'HS_STATE': 'hs_state',
+    'REND_QUERY': 'rend_query',
+    'TIME_CREATED': 'created',
+    'OLD_PURPOSE': 'old_purpose',
+    'OLD_HS_STATE': 'old_hs_state',
   }
   _VERSION_ADDED = stem.version.Requirement.EVENT_CIRC_MINOR
 
@@ -413,7 +454,7 @@ class CircMinorEvent(Event):
       try:
         self.created = str_tools._parse_iso_timestamp(self.created)
       except ValueError as exc:
-        raise stem.ProtocolError("Unable to parse create date (%s): %s" % (exc, self))
+        raise stem.ProtocolError('Unable to parse create date (%s): %s' % (exc, self))
 
     if not tor_tools.is_valid_circuit_id(self.id):
       raise stem.ProtocolError("Circuit IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
@@ -438,15 +479,15 @@ class ClientsSeenEvent(Event):
   """
 
   _KEYWORD_ARGS = {
-    "TimeStarted": "start_time",
-    "CountrySummary": "locales",
-    "IPVersions": "ip_versions",
+    'TimeStarted': 'start_time',
+    'CountrySummary': 'locales',
+    'IPVersions': 'ip_versions',
   }
   _VERSION_ADDED = stem.version.Requirement.EVENT_CLIENTS_SEEN
 
   def _parse(self):
     if self.start_time is not None:
-      self.start_time = datetime.datetime.strptime(self.start_time, "%Y-%m-%d %H:%M:%S")
+      self.start_time = datetime.datetime.strptime(self.start_time, '%Y-%m-%d %H:%M:%S')
 
     if self.locales is not None:
       locale_to_count = {}
@@ -460,7 +501,7 @@ class ClientsSeenEvent(Event):
         if len(locale) != 2:
           raise stem.ProtocolError("Locales should be a two character code, got '%s': %s" % (locale, self))
         elif not count.isdigit():
-          raise stem.ProtocolError("Locale count was non-numeric (%s): %s" % (count, self))
+          raise stem.ProtocolError('Locale count was non-numeric (%s): %s' % (count, self))
         elif locale in locale_to_count:
           raise stem.ProtocolError("CountrySummary had multiple mappings for '%s': %s" % (locale, self))
 
@@ -478,7 +519,7 @@ class ClientsSeenEvent(Event):
         protocol, count = entry.split('=', 1)
 
         if not count.isdigit():
-          raise stem.ProtocolError("IP protocol count was non-numeric (%s): %s" % (count, self))
+          raise stem.ProtocolError('IP protocol count was non-numeric (%s): %s' % (count, self))
 
         protocol_to_count[protocol] = int(count)
 
@@ -550,7 +591,7 @@ class GuardEvent(Event):
   """
 
   _VERSION_ADDED = stem.version.Requirement.EVENT_GUARD
-  _POSITIONAL_ARGS = ("guard_type", "endpoint", "status")
+  _POSITIONAL_ARGS = ('guard_type', 'endpoint', 'status')
 
   def _parse(self):
     self.endpoint_fingerprint = None
@@ -560,12 +601,46 @@ class GuardEvent(Event):
       self.endpoint_fingerprint, self.endpoint_nickname = \
         stem.control._parse_circ_entry(self.endpoint)
     except stem.ProtocolError:
-      raise stem.ProtocolError("ORCONN's endpoint doesn't match a ServerSpec: %s" % self)
+      raise stem.ProtocolError("GUARD's endpoint doesn't match a ServerSpec: %s" % self)
 
     self._log_if_unrecognized('guard_type', stem.GuardType)
     self._log_if_unrecognized('status', stem.GuardStatus)
 
 
+class HSDescEvent(Event):
+  """
+  Event triggered when we fetch a hidden service descriptor that presently isn't in our cache.
+
+  The HS_DESC event was introduced in tor version 0.2.5.2-alpha.
+
+  .. versionadded:: 1.2.0
+
+  :var stem.HSDescAction action: what is happening with the descriptor
+  :var str address: hidden service address
+  :var stem.HSAuth authentication: service's authentication method
+  :var str directory: hidden service directory servicing the request
+  :var str directory_fingerprint: hidden service directory's finterprint
+  :var str directory_nickname: hidden service directory's nickname if it was provided
+  :var str descriptor_id: descriptor identifier
+  """
+
+  _VERSION_ADDED = stem.version.Requirement.EVENT_HS_DESC
+  _POSITIONAL_ARGS = ('action', 'address', 'authentication', 'directory', 'descriptor_id')
+
+  def _parse(self):
+    self.directory_fingerprint = None
+    self.directory_nickname = None
+
+    try:
+      self.directory_fingerprint, self.directory_nickname = \
+        stem.control._parse_circ_entry(self.directory)
+    except stem.ProtocolError:
+      raise stem.ProtocolError("HS_DESC's directory doesn't match a ServerSpec: %s" % self)
+
+    self._log_if_unrecognized('action', stem.HSDescAction)
+    self._log_if_unrecognized('authentication', stem.HSAuth)
+
+
 class LogEvent(Event):
   """
   Tor logging event. These are the most visible kind of event since, by
@@ -587,7 +662,7 @@ class LogEvent(Event):
     # message is our content, minus the runlevel and ending "OK" if a
     # multi-line message
 
-    self.message = str(self)[len(self.runlevel) + 1:].rstrip("\nOK")
+    self.message = str(self)[len(self.runlevel) + 1:].rstrip('\nOK')
 
 
 class NetworkStatusEvent(Event):
@@ -604,7 +679,7 @@ class NetworkStatusEvent(Event):
   _VERSION_ADDED = stem.version.Requirement.EVENT_NS
 
   def _parse(self):
-    content = str(self).lstrip("NS\n").rstrip("\nOK")
+    content = str(self).lstrip('NS\n').rstrip('\nOK')
 
     self.desc = list(stem.descriptor.router_status_entry._parse_file(
       io.BytesIO(str_tools._to_bytes(content)),
@@ -629,7 +704,7 @@ class NewConsensusEvent(Event):
   _VERSION_ADDED = stem.version.Requirement.EVENT_NEWCONSENSUS
 
   def _parse(self):
-    content = str(self).lstrip("NEWCONSENSUS\n").rstrip("\nOK")
+    content = str(self).lstrip('NEWCONSENSUS\n').rstrip('\nOK')
 
     self.desc = list(stem.descriptor.router_status_entry._parse_file(
       io.BytesIO(str_tools._to_bytes(content)),
@@ -670,8 +745,13 @@ class ORConnEvent(Event):
   The derived 'endpoint_*' attributes are generally more useful.
 
   The ORCONN event was one of the first Control Protocol V1 events and was
-  introduced in tor version 0.1.1.1-alpha.
+  introduced in tor version 0.1.1.1-alpha. Its id attribute was added in
+  version 0.2.5.2-alpha.
 
+  .. versionchanged:: 1.2.0
+     Added the id attribute.
+
+  :var str id: connection identifier
   :var str endpoint: relay that the event concerns
   :var str endpoint_fingerprint: endpoint's finterprint if it was provided
   :var str endpoint_nickname: endpoint's nickname if it was provided
@@ -682,10 +762,11 @@ class ORConnEvent(Event):
   :var int circ_count: number of established and pending circuits
   """
 
-  _POSITIONAL_ARGS = ("endpoint", "status")
+  _POSITIONAL_ARGS = ('endpoint', 'status')
   _KEYWORD_ARGS = {
-    "REASON": "reason",
-    "NCIRCS": "circ_count",
+    'REASON': 'reason',
+    'NCIRCS': 'circ_count',
+    'ID': 'id',
   }
 
   def _parse(self):
@@ -711,10 +792,13 @@ class ORConnEvent(Event):
 
     if self.circ_count is not None:
       if not self.circ_count.isdigit():
-        raise stem.ProtocolError("ORCONN event got a non-numeric circuit count (%s): %s" % (self.circ_count, self))
+        raise stem.ProtocolError('ORCONN event got a non-numeric circuit count (%s): %s' % (self.circ_count, self))
 
       self.circ_count = int(self.circ_count)
 
+    if self.id and not tor_tools.is_valid_connection_id(self.id):
+      raise stem.ProtocolError("Connection IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
+
     self._log_if_unrecognized('status', stem.ORStatus)
     self._log_if_unrecognized('reason', stem.ORClosureReason)
 
@@ -736,7 +820,7 @@ class SignalEvent(Event):
   :var stem.Signal signal: signal that tor received
   """
 
-  _POSITIONAL_ARGS = ("signal",)
+  _POSITIONAL_ARGS = ('signal',)
   _VERSION_ADDED = stem.version.Requirement.EVENT_SIGNAL
 
   def _parse(self):
@@ -767,7 +851,7 @@ class StatusEvent(Event):
   :var str message: logged message
   """
 
-  _POSITIONAL_ARGS = ("runlevel", "action")
+  _POSITIONAL_ARGS = ('runlevel', 'action')
   _VERSION_ADDED = stem.version.Requirement.EVENT_STATUS
 
   def _parse(self):
@@ -805,13 +889,13 @@ class StreamEvent(Event):
   :var stem.StreamPurpose purpose: purpose for the stream
   """
 
-  _POSITIONAL_ARGS = ("id", "status", "circ_id", "target")
+  _POSITIONAL_ARGS = ('id', 'status', 'circ_id', 'target')
   _KEYWORD_ARGS = {
-    "REASON": "reason",
-    "REMOTE_REASON": "remote_reason",
-    "SOURCE": "source",
-    "SOURCE_ADDR": "source_addr",
-    "PURPOSE": "purpose",
+    'REASON': 'reason',
+    'REMOTE_REASON': 'remote_reason',
+    'SOURCE': 'source',
+    'SOURCE_ADDR': 'source_addr',
+    'PURPOSE': 'purpose',
   }
 
   def _parse(self):
@@ -846,7 +930,7 @@ class StreamEvent(Event):
 
     # spec specifies a circ_id of zero if the stream is unattached
 
-    if self.circ_id == "0":
+    if self.circ_id == '0':
       self.circ_id = None
 
     self._log_if_unrecognized('reason', stem.StreamClosureReason)
@@ -866,16 +950,16 @@ class StreamBwEvent(Event):
   :var long read: bytes received by the application
   """
 
-  _POSITIONAL_ARGS = ("id", "written", "read")
+  _POSITIONAL_ARGS = ('id', 'written', 'read')
   _VERSION_ADDED = stem.version.Requirement.EVENT_STREAM_BW
 
   def _parse(self):
     if not tor_tools.is_valid_stream_id(self.id):
       raise stem.ProtocolError("Stream IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
     elif not self.written:
-      raise stem.ProtocolError("STREAM_BW event is missing its written value")
+      raise stem.ProtocolError('STREAM_BW event is missing its written value')
     elif not self.read:
-      raise stem.ProtocolError("STREAM_BW event is missing its read value")
+      raise stem.ProtocolError('STREAM_BW event is missing its read value')
     elif not self.read.isdigit() or not self.written.isdigit():
       raise stem.ProtocolError("A STREAM_BW event's bytes sent and received should be a positive numeric value, received: %s" % self)
 
@@ -889,6 +973,8 @@ class TransportLaunchedEvent(Event):
 
   The TRANSPORT_LAUNCHED event was introduced in tor version 0.2.5.0-alpha.
 
+  .. versionadded:: 1.1.0
+
   :var str type: 'server' or 'client'
   :var str name: name of the pluggable transport
   :var str address: IPv4 or IPv6 address where the transport is listening for
@@ -896,7 +982,7 @@ class TransportLaunchedEvent(Event):
   :var int port: port where the transport is listening for connections
   """
 
-  _POSITIONAL_ARGS = ("type", "name", "address", "port")
+  _POSITIONAL_ARGS = ('type', 'name', 'address', 'port')
   _VERSION_ADDED = stem.version.Requirement.EVENT_TRANSPORT_LAUNCHED
 
   def _parse(self):
@@ -908,38 +994,264 @@ class TransportLaunchedEvent(Event):
       raise stem.ProtocolError("Transport address isn't a valid IPv4 or IPv6 address: %s" % self)
 
     if not connection.is_valid_port(self.port):
-      raise stem.ProtocolError("Transport port is invalid: %s" % self)
+      raise stem.ProtocolError('Transport port is invalid: %s' % self)
 
     self.port = int(self.port)
 
+
+class ConnectionBandwidthEvent(Event):
+  """
+  Event emitted every second with the bytes sent and received by tor on a
+  per-connection basis.
+
+  The CONN_BW event was introduced in tor version 0.2.5.2-alpha.
+
+  .. versionadded:: 1.2.0
+
+  :var str id: connection identifier
+  :var stem.ConnectionType type: connection type
+  :var long read: bytes received by tor that second
+  :var long written: bytes sent by tor that second
+  """
+
+  _KEYWORD_ARGS = {
+    'ID': 'id',
+    'TYPE': 'type',
+    'READ': 'read',
+    'WRITTEN': 'written',
+  }
+
+  _VERSION_ADDED = stem.version.Requirement.EVENT_CONN_BW
+
+  def _parse(self):
+    if not self.id:
+      raise stem.ProtocolError('CONN_BW event is missing its id')
+    elif not self.type:
+      raise stem.ProtocolError('CONN_BW event is missing its type')
+    elif not self.read:
+      raise stem.ProtocolError('CONN_BW event is missing its read value')
+    elif not self.written:
+      raise stem.ProtocolError('CONN_BW event is missing its written value')
+    elif not self.read.isdigit() or not self.written.isdigit():
+      raise stem.ProtocolError("A CONN_BW event's bytes sent and received should be a positive numeric value, received: %s" % self)
+    elif not tor_tools.is_valid_connection_id(self.id):
+      raise stem.ProtocolError("Connection IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
+
+    self.read = long(self.read)
+    self.written = long(self.written)
+
+    self._log_if_unrecognized('type', stem.ConnectionType)
+
+
+class CircuitBandwidthEvent(Event):
+  """
+  Event emitted every second with the bytes sent and received by tor on a
+  per-circuit basis.
+
+  The CIRC_BW event was introduced in tor version 0.2.5.2-alpha.
+
+  .. versionadded:: 1.2.0
+
+  :var str id: circuit identifier
+  :var long read: bytes received by tor that second
+  :var long written: bytes sent by tor that second
+  """
+
+  _KEYWORD_ARGS = {
+    'ID': 'id',
+    'READ': 'read',
+    'WRITTEN': 'written',
+  }
+
+  _VERSION_ADDED = stem.version.Requirement.EVENT_CIRC_BW
+
+  def _parse(self):
+    if not self.id:
+      raise stem.ProtocolError('CIRC_BW event is missing its id')
+    elif not self.read:
+      raise stem.ProtocolError('CIRC_BW event is missing its read value')
+    elif not self.written:
+      raise stem.ProtocolError('CIRC_BW event is missing its written value')
+    elif not self.read.isdigit() or not self.written.isdigit():
+      raise stem.ProtocolError("A CIRC_BW event's bytes sent and received should be a positive numeric value, received: %s" % self)
+    elif not tor_tools.is_valid_circuit_id(self.id):
+      raise stem.ProtocolError("Circuit IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
+
+    self.read = long(self.read)
+    self.written = long(self.written)
+
+
+class CellStatsEvent(Event):
+  """
+  Event emitted every second with a count of the number of cells types broken
+  down by the circuit. **These events are only emitted if TestingTorNetwork is
+  set.**
+
+  The CELL_STATS event was introduced in tor version 0.2.5.2-alpha.
+
+  .. versionadded:: 1.2.0
+
+  :var str id: circuit identifier
+  :var str inbound_queue: inbound queue identifier
+  :var str inbound_connection: inbound connection identifier
+  :var dict inbound_added: mapping of added inbound cell types to their count
+  :var dict inbound_removed: mapping of removed inbound cell types to their count
+  :var dict inbound_time: mapping of inbound cell types to the time they took to write in milliseconds
+  :var str outbound_queue: outbound queue identifier
+  :var str outbound_connection: outbound connection identifier
+  :var dict outbound_added: mapping of added outbound cell types to their count
+  :var dict outbound_removed: mapping of removed outbound cell types to their count
+  :var dict outbound_time: mapping of outbound cell types to the time they took to write in milliseconds
+  """
+
+  _KEYWORD_ARGS = {
+    'ID': 'id',
+    'InboundQueue': 'inbound_queue',
+    'InboundConn': 'inbound_connection',
+    'InboundAdded': 'inbound_added',
+    'InboundRemoved': 'inbound_removed',
+    'InboundTime': 'inbound_time',
+    'OutboundQueue': 'outbound_queue',
+    'OutboundConn': 'outbound_connection',
+    'OutboundAdded': 'outbound_added',
+    'OutboundRemoved': 'outbound_removed',
+    'OutboundTime': 'outbound_time',
+  }
+
+  _VERSION_ADDED = stem.version.Requirement.EVENT_CELL_STATS
+
+  def _parse(self):
+    if self.id and not tor_tools.is_valid_circuit_id(self.id):
+      raise stem.ProtocolError("Circuit IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
+    elif self.inbound_queue and not tor_tools.is_valid_circuit_id(self.inbound_queue):
+      raise stem.ProtocolError("Queue IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.inbound_queue, self))
+    elif self.inbound_connection and not tor_tools.is_valid_connection_id(self.inbound_connection):
+      raise stem.ProtocolError("Connection IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.inbound_connection, self))
+    elif self.outbound_queue and not tor_tools.is_valid_circuit_id(self.outbound_queue):
+      raise stem.ProtocolError("Queue IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.outbound_queue, self))
+    elif self.outbound_connection and not tor_tools.is_valid_connection_id(self.outbound_connection):
+      raise stem.ProtocolError("Connection IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.outbound_connection, self))
+
+    self.inbound_added = _parse_cell_type_mapping(self.inbound_added)
+    self.inbound_removed = _parse_cell_type_mapping(self.inbound_removed)
+    self.inbound_time = _parse_cell_type_mapping(self.inbound_time)
+    self.outbound_added = _parse_cell_type_mapping(self.outbound_added)
+    self.outbound_removed = _parse_cell_type_mapping(self.outbound_removed)
+    self.outbound_time = _parse_cell_type_mapping(self.outbound_time)
+
+
+class TokenBucketEmptyEvent(Event):
+  """
+  Event emitted when refilling an empty token bucket. **These events are only
+  emitted if TestingTorNetwork is set.**
+
+  The TB_EMPTY event was introduced in tor version 0.2.5.2-alpha.
+
+  .. versionadded:: 1.2.0
+
+  :var stem.TokenBucket bucket: bucket being refilled
+  :var str id: connection identifier
+  :var int read: time in milliseconds since the read bucket was last refilled
+  :var int written: time in milliseconds since the write bucket was last refilled
+  :var int last_refill: time in milliseconds the bucket has been empty since last refilled
+  """
+
+  _POSITIONAL_ARGS = ('bucket',)
+  _KEYWORD_ARGS = {
+    'ID': 'id',
+    'READ': 'read',
+    'WRITTEN': 'written',
+    'LAST': 'last_refill',
+  }
+
+  _VERSION_ADDED = stem.version.Requirement.EVENT_TB_EMPTY
+
+  def _parse(self):
+    if self.id and not tor_tools.is_valid_connection_id(self.id):
+      raise stem.ProtocolError("Connection IDs must be one to sixteen alphanumeric characters, got '%s': %s" % (self.id, self))
+    elif not self.read.isdigit():
+      raise stem.ProtocolError("A TB_EMPTY's READ value should be a positive numeric value, received: %s" % self)
+    elif not self.written.isdigit():
+      raise stem.ProtocolError("A TB_EMPTY's WRITTEN value should be a positive numeric value, received: %s" % self)
+    elif not self.last_refill.isdigit():
+      raise stem.ProtocolError("A TB_EMPTY's LAST value should be a positive numeric value, received: %s" % self)
+
+    self.read = int(self.read)
+    self.written = int(self.written)
+    self.last_refill = int(self.last_refill)
+
+    self._log_if_unrecognized('bucket', stem.TokenBucket)
+
+
+def _parse_cell_type_mapping(mapping):
+  """
+  Parses a mapping of the form...
+
+    key1:value1,key2:value2...
+
+  ... in which keys are strings and values are integers.
+
+  :param str mapping: value to be parsed
+
+  :returns: dict of **str => int** mappings
+
+  :rasies: **stem.ProtocolError** if unable to parse the mapping
+  """
+
+  if mapping is None:
+    return None
+
+  results = {}
+
+  for entry in mapping.split(','):
+    if not ':' in entry:
+      raise stem.ProtocolError("Mappings are expected to be of the form 'key:value', got '%s': %s" % (entry, mapping))
+
+    key, value = entry.split(':', 1)
+
+    if not CELL_TYPE.match(key):
+      raise stem.ProtocolError("Key had invalid characters, got '%s': %s" % (key, mapping))
+    elif not value.isdigit():
+      raise stem.ProtocolError("Values should just be integers, got '%s': %s" % (value, mapping))
+
+    results[key] = int(value)
+
+  return results
+
+
 EVENT_TYPE_TO_CLASS = {
-  "ADDRMAP": AddrMapEvent,
-  "AUTHDIR_NEWDESCS": AuthDirNewDescEvent,
-  "BUILDTIMEOUT_SET": BuildTimeoutSetEvent,
-  "BW": BandwidthEvent,
-  "CIRC": CircuitEvent,
-  "CIRC_MINOR": CircMinorEvent,
-  "CLIENTS_SEEN": ClientsSeenEvent,
-  "CONF_CHANGED": ConfChangedEvent,
-  "DEBUG": LogEvent,
-  "DESCCHANGED": DescChangedEvent,
-  "ERR": LogEvent,
-  "GUARD": GuardEvent,
-  "INFO": LogEvent,
-  "NEWCONSENSUS": NewConsensusEvent,
-  "NEWDESC": NewDescEvent,
-  "NOTICE": LogEvent,
-  "NS": NetworkStatusEvent,
-  "ORCONN": ORConnEvent,
-  "SIGNAL": SignalEvent,
-  "STATUS_CLIENT": StatusEvent,
-  "STATUS_GENERAL": StatusEvent,
-  "STATUS_SERVER": StatusEvent,
-  "STREAM": StreamEvent,
-  "STREAM_BW": StreamBwEvent,
-  "TRANSPORT_LAUNCHED": TransportLaunchedEvent,
-  "WARN": LogEvent,
+  'ADDRMAP': AddrMapEvent,
+  'AUTHDIR_NEWDESCS': AuthDirNewDescEvent,
+  'BUILDTIMEOUT_SET': BuildTimeoutSetEvent,
+  'BW': BandwidthEvent,
+  'CELL_STATS': CellStatsEvent,
+  'CIRC': CircuitEvent,
+  'CIRC_BW': CircuitBandwidthEvent,
+  'CIRC_MINOR': CircMinorEvent,
+  'CLIENTS_SEEN': ClientsSeenEvent,
+  'CONF_CHANGED': ConfChangedEvent,
+  'CONN_BW': ConnectionBandwidthEvent,
+  'DEBUG': LogEvent,
+  'DESCCHANGED': DescChangedEvent,
+  'ERR': LogEvent,
+  'GUARD': GuardEvent,
+  'HS_DESC': HSDescEvent,
+  'INFO': LogEvent,
+  'NEWCONSENSUS': NewConsensusEvent,
+  'NEWDESC': NewDescEvent,
+  'NOTICE': LogEvent,
+  'NS': NetworkStatusEvent,
+  'ORCONN': ORConnEvent,
+  'SIGNAL': SignalEvent,
+  'STATUS_CLIENT': StatusEvent,
+  'STATUS_GENERAL': StatusEvent,
+  'STATUS_SERVER': StatusEvent,
+  'STREAM': StreamEvent,
+  'STREAM_BW': StreamBwEvent,
+  'TB_EMPTY': TokenBucketEmptyEvent,
+  'TRANSPORT_LAUNCHED': TransportLaunchedEvent,
+  'WARN': LogEvent,
 
   # accounting for a bug in tor 0.2.0.22
-  "STATUS_SEVER": StatusEvent,
+  'STATUS_SEVER': StatusEvent,
 }
