@@ -22,7 +22,7 @@ import test.network
 import test.runner
 
 from stem import Flag, Signal
-from stem.control import EventType, State
+from stem.control import EventType, Listener, State
 from stem.exit_policy import ExitPolicy
 from stem.version import Requirement
 
@@ -49,7 +49,7 @@ class TestController(unittest.TestCase):
       with stem.control.Controller.from_port(port = test.runner.CONTROL_PORT) as controller:
         self.assertTrue(isinstance(controller, stem.control.Controller))
     else:
-      self.assertRaises(stem.SocketError, stem.control.Controller.from_port, "127.0.0.1", test.runner.CONTROL_PORT)
+      self.assertRaises(stem.SocketError, stem.control.Controller.from_port, '127.0.0.1', test.runner.CONTROL_PORT)
 
   def test_from_socket_file(self):
     """
@@ -103,7 +103,7 @@ class TestController(unittest.TestCase):
       self.assertEqual(State.RESET, state_type)
       self.assertTrue(state_timestamp > before and state_timestamp < after)
 
-      controller.reset_conf("__OwningControllerProcess")
+      controller.reset_conf('__OwningControllerProcess')
 
   def test_event_handling(self):
     """
@@ -257,28 +257,28 @@ class TestController(unittest.TestCase):
       # successful single query
 
       torrc_path = runner.get_torrc_path()
-      self.assertEqual(torrc_path, controller.get_info("config-file"))
-      self.assertEqual(torrc_path, controller.get_info("config-file", "ho hum"))
+      self.assertEqual(torrc_path, controller.get_info('config-file'))
+      self.assertEqual(torrc_path, controller.get_info('config-file', 'ho hum'))
 
-      expected = {"config-file": torrc_path}
-      self.assertEqual(expected, controller.get_info(["config-file"]))
-      self.assertEqual(expected, controller.get_info(["config-file"], "ho hum"))
+      expected = {'config-file': torrc_path}
+      self.assertEqual(expected, controller.get_info(['config-file']))
+      self.assertEqual(expected, controller.get_info(['config-file'], 'ho hum'))
 
       # successful batch query, we don't know the values so just checking for
       # the keys
 
-      getinfo_params = set(["version", "config-file", "config/names"])
-      self.assertEqual(getinfo_params, set(controller.get_info(["version", "config-file", "config/names"]).keys()))
+      getinfo_params = set(['version', 'config-file', 'config/names'])
+      self.assertEqual(getinfo_params, set(controller.get_info(['version', 'config-file', 'config/names']).keys()))
 
       # non-existant option
 
-      self.assertRaises(stem.ControllerError, controller.get_info, "blarg")
-      self.assertEqual("ho hum", controller.get_info("blarg", "ho hum"))
+      self.assertRaises(stem.ControllerError, controller.get_info, 'blarg')
+      self.assertEqual('ho hum', controller.get_info('blarg', 'ho hum'))
 
       # empty input
 
-      self.assertRaises(stem.ControllerError, controller.get_info, "")
-      self.assertEqual("ho hum", controller.get_info("", "ho hum"))
+      self.assertRaises(stem.ControllerError, controller.get_info, '')
+      self.assertEqual('ho hum', controller.get_info('', 'ho hum'))
 
       self.assertEqual({}, controller.get_info([]))
       self.assertEqual({}, controller.get_info([], {}))
@@ -405,55 +405,55 @@ class TestController(unittest.TestCase):
 
       if isinstance(control_socket, stem.socket.ControlPort):
         connection_value = str(control_socket.get_port())
-        config_key = "ControlPort"
+        config_key = 'ControlPort'
       elif isinstance(control_socket, stem.socket.ControlSocketFile):
         connection_value = str(control_socket.get_socket_path())
-        config_key = "ControlSocket"
+        config_key = 'ControlSocket'
 
       # successful single query
       self.assertEqual(connection_value, controller.get_conf(config_key))
-      self.assertEqual(connection_value, controller.get_conf(config_key, "la-di-dah"))
+      self.assertEqual(connection_value, controller.get_conf(config_key, 'la-di-dah'))
 
       # succeessful batch query
       expected = {config_key: [connection_value]}
       self.assertEqual(expected, controller.get_conf_map([config_key]))
-      self.assertEqual(expected, controller.get_conf_map([config_key], "la-di-dah"))
+      self.assertEqual(expected, controller.get_conf_map([config_key], 'la-di-dah'))
 
-      request_params = ["ControlPORT", "dirport", "datadirectory"]
+      request_params = ['ControlPORT', 'dirport', 'datadirectory']
       reply_params = controller.get_conf_map(request_params, multiple=False).keys()
       self.assertEqual(set(request_params), set(reply_params))
 
       # queries an option that is unset
 
-      self.assertEqual(None, controller.get_conf("HTTPSProxy"))
-      self.assertEqual("la-di-dah", controller.get_conf("HTTPSProxy", "la-di-dah"))
-      self.assertEqual([], controller.get_conf("HTTPSProxy", [], multiple = True))
+      self.assertEqual(None, controller.get_conf('HTTPSProxy'))
+      self.assertEqual('la-di-dah', controller.get_conf('HTTPSProxy', 'la-di-dah'))
+      self.assertEqual([], controller.get_conf('HTTPSProxy', [], multiple = True))
 
       # non-existant option(s)
-      self.assertRaises(stem.InvalidArguments, controller.get_conf, "blarg")
-      self.assertEqual("la-di-dah", controller.get_conf("blarg", "la-di-dah"))
-      self.assertRaises(stem.InvalidArguments, controller.get_conf_map, "blarg")
-      self.assertEqual({"blarg": "la-di-dah"}, controller.get_conf_map("blarg", "la-di-dah"))
+      self.assertRaises(stem.InvalidArguments, controller.get_conf, 'blarg')
+      self.assertEqual('la-di-dah', controller.get_conf('blarg', 'la-di-dah'))
+      self.assertRaises(stem.InvalidArguments, controller.get_conf_map, 'blarg')
+      self.assertEqual({'blarg': 'la-di-dah'}, controller.get_conf_map('blarg', 'la-di-dah'))
 
-      self.assertRaises(stem.InvalidRequest, controller.get_conf_map, ["blarg", "huadf"], multiple = True)
-      self.assertEqual({"erfusdj": "la-di-dah", "afiafj": "la-di-dah"}, controller.get_conf_map(["erfusdj", "afiafj"], "la-di-dah", multiple = True))
+      self.assertRaises(stem.InvalidRequest, controller.get_conf_map, ['blarg', 'huadf'], multiple = True)
+      self.assertEqual({'erfusdj': 'la-di-dah', 'afiafj': 'la-di-dah'}, controller.get_conf_map(['erfusdj', 'afiafj'], 'la-di-dah', multiple = True))
 
       # multivalue configuration keys
-      nodefamilies = [("abc", "xyz", "pqrs"), ("mno", "tuv", "wxyz")]
-      controller.msg("SETCONF %s" % " ".join(["nodefamily=\"" + ",".join(x) + "\"" for x in nodefamilies]))
-      self.assertEqual([",".join(n) for n in nodefamilies], controller.get_conf("nodefamily", multiple = True))
-      controller.msg("RESETCONF NodeFamily")
+      nodefamilies = [('abc', 'xyz', 'pqrs'), ('mno', 'tuv', 'wxyz')]
+      controller.msg('SETCONF %s' % ' '.join(['nodefamily="' + ','.join(x) + '"' for x in nodefamilies]))
+      self.assertEqual([','.join(n) for n in nodefamilies], controller.get_conf('nodefamily', multiple = True))
+      controller.msg('RESETCONF NodeFamily')
 
       # empty input
-      self.assertEqual(None, controller.get_conf(""))
+      self.assertEqual(None, controller.get_conf(''))
       self.assertEqual({}, controller.get_conf_map([]))
-      self.assertEqual({}, controller.get_conf_map([""]))
-      self.assertEqual(None, controller.get_conf("          "))
-      self.assertEqual({}, controller.get_conf_map(["    ", "        "]))
+      self.assertEqual({}, controller.get_conf_map(['']))
+      self.assertEqual(None, controller.get_conf('          '))
+      self.assertEqual({}, controller.get_conf_map(['    ', '        ']))
 
-      self.assertEqual("la-di-dah", controller.get_conf("", "la-di-dah"))
-      self.assertEqual({}, controller.get_conf_map("", "la-di-dah"))
-      self.assertEqual({}, controller.get_conf_map([], "la-di-dah"))
+      self.assertEqual('la-di-dah', controller.get_conf('', 'la-di-dah'))
+      self.assertEqual({}, controller.get_conf_map('', 'la-di-dah'))
+      self.assertEqual({}, controller.get_conf_map([], 'la-di-dah'))
 
   def test_set_conf(self):
     """
@@ -470,62 +470,62 @@ class TestController(unittest.TestCase):
     with runner.get_tor_controller() as controller:
       try:
         # successfully set a single option
-        connlimit = int(controller.get_conf("ConnLimit"))
-        controller.set_conf("connlimit", str(connlimit - 1))
-        self.assertEqual(connlimit - 1, int(controller.get_conf("ConnLimit")))
+        connlimit = int(controller.get_conf('ConnLimit'))
+        controller.set_conf('connlimit', str(connlimit - 1))
+        self.assertEqual(connlimit - 1, int(controller.get_conf('ConnLimit')))
 
         # successfully set a single list option
-        exit_policy = ["accept *:7777", "reject *:*"]
-        controller.set_conf("ExitPolicy", exit_policy)
-        self.assertEqual(exit_policy, controller.get_conf("ExitPolicy", multiple = True))
+        exit_policy = ['accept *:7777', 'reject *:*']
+        controller.set_conf('ExitPolicy', exit_policy)
+        self.assertEqual(exit_policy, controller.get_conf('ExitPolicy', multiple = True))
 
         # fail to set a single option
         try:
-          controller.set_conf("invalidkeyboo", "abcde")
+          controller.set_conf('invalidkeyboo', 'abcde')
           self.fail()
         except stem.InvalidArguments as exc:
-          self.assertEqual(["invalidkeyboo"], exc.arguments)
+          self.assertEqual(['invalidkeyboo'], exc.arguments)
 
         # resets configuration parameters
-        controller.reset_conf("ConnLimit", "ExitPolicy")
-        self.assertEqual(connlimit, int(controller.get_conf("ConnLimit")))
-        self.assertEqual(None, controller.get_conf("ExitPolicy"))
+        controller.reset_conf('ConnLimit', 'ExitPolicy')
+        self.assertEqual(connlimit, int(controller.get_conf('ConnLimit')))
+        self.assertEqual(None, controller.get_conf('ExitPolicy'))
 
         # successfully sets multiple config options
         controller.set_options({
-          "connlimit": str(connlimit - 2),
-          "contactinfo": "stem@testing",
+          'connlimit': str(connlimit - 2),
+          'contactinfo': 'stem@testing',
         })
 
-        self.assertEqual(connlimit - 2, int(controller.get_conf("ConnLimit")))
-        self.assertEqual("stem@testing", controller.get_conf("contactinfo"))
+        self.assertEqual(connlimit - 2, int(controller.get_conf('ConnLimit')))
+        self.assertEqual('stem@testing', controller.get_conf('contactinfo'))
 
         # fail to set multiple config options
         try:
           controller.set_options({
-            "contactinfo": "stem@testing",
-            "bombay": "vadapav",
+            'contactinfo': 'stem@testing',
+            'bombay': 'vadapav',
           })
           self.fail()
         except stem.InvalidArguments as exc:
-          self.assertEqual(["bombay"], exc.arguments)
+          self.assertEqual(['bombay'], exc.arguments)
 
         # context-sensitive keys (the only retched things for which order matters)
         controller.set_options((
-          ("HiddenServiceDir", tmpdir),
-          ("HiddenServicePort", "17234 127.0.0.1:17235"),
+          ('HiddenServiceDir', tmpdir),
+          ('HiddenServicePort', '17234 127.0.0.1:17235'),
         ))
 
-        self.assertEqual(tmpdir, controller.get_conf("HiddenServiceDir"))
-        self.assertEqual("17234 127.0.0.1:17235", controller.get_conf("HiddenServicePort"))
+        self.assertEqual(tmpdir, controller.get_conf('HiddenServiceDir'))
+        self.assertEqual('17234 127.0.0.1:17235', controller.get_conf('HiddenServicePort'))
       finally:
         # reverts configuration changes
         controller.set_options((
-          ("ExitPolicy", "reject *:*"),
-          ("ConnLimit", None),
-          ("ContactInfo", None),
-          ("HiddenServiceDir", None),
-          ("HiddenServicePort", None),
+          ('ExitPolicy', 'reject *:*'),
+          ('ConnLimit', None),
+          ('ContactInfo', None),
+          ('HiddenServiceDir', None),
+          ('HiddenServicePort', None),
         ), reset = True)
 
         shutil.rmtree(tmpdir)
@@ -554,22 +554,22 @@ class TestController(unittest.TestCase):
         #   ("/home/atagar/Desktop/stem/test/data"->"/home/atagar/.tor") is not
         #   allowed.
 
-        self.assertRaises(stem.InvalidRequest, controller.load_conf, "ContactInfo confloaded")
+        self.assertRaises(stem.InvalidRequest, controller.load_conf, 'ContactInfo confloaded')
 
         try:
-          controller.load_conf("Blahblah blah")
+          controller.load_conf('Blahblah blah')
           self.fail()
         except stem.InvalidArguments as exc:
-          self.assertEqual(["Blahblah"], exc.arguments)
+          self.assertEqual(['Blahblah'], exc.arguments)
 
         # valid config
 
-        controller.load_conf(runner.get_torrc_contents() + "\nContactInfo confloaded\n")
-        self.assertEqual("confloaded", controller.get_conf("ContactInfo"))
+        controller.load_conf(runner.get_torrc_contents() + '\nContactInfo confloaded\n')
+        self.assertEqual('confloaded', controller.get_conf('ContactInfo'))
       finally:
         # reload original valid config
         controller.load_conf(oldconf)
-        controller.reset_conf("__OwningControllerProcess")
+        controller.reset_conf('__OwningControllerProcess')
 
   def test_saveconf(self):
     if test.runner.require_control(self):
@@ -583,19 +583,65 @@ class TestController(unittest.TestCase):
       oldconf = runner.get_torrc_contents()
 
       try:
-        controller.set_conf("ContactInfo", "confsaved")
+        controller.set_conf('ContactInfo', 'confsaved')
         controller.save_conf()
 
         with open(runner.get_torrc_path()) as torrcfile:
-          self.assertTrue("\nContactInfo confsaved\n" in torrcfile.read())
+          self.assertTrue('\nContactInfo confsaved\n' in torrcfile.read())
       finally:
         controller.load_conf(oldconf)
         controller.save_conf()
-        controller.reset_conf("__OwningControllerProcess")
+        controller.reset_conf('__OwningControllerProcess')
 
-  def test_get_socks_ports(self):
+  def test_get_ports(self):
     """
-    Test Controller.get_socks_ports against a running tor instance.
+    Test Controller.get_ports against a running tor instance.
+    """
+
+    if test.runner.require_control(self):
+      return
+
+    runner = test.runner.get_runner()
+
+    with runner.get_tor_controller() as controller:
+      self.assertEqual([], controller.get_ports(Listener.OR))
+      self.assertEqual([], controller.get_ports(Listener.DIR))
+      self.assertEqual([test.runner.SOCKS_PORT], controller.get_ports(Listener.SOCKS))
+      self.assertEqual([], controller.get_ports(Listener.TRANS))
+      self.assertEqual([], controller.get_ports(Listener.NATD))
+      self.assertEqual([], controller.get_ports(Listener.DNS))
+
+      if test.runner.Torrc.PORT in runner.get_options():
+        self.assertEqual([test.runner.CONTROL_PORT], controller.get_ports(Listener.CONTROL))
+      else:
+        self.assertEqual([], controller.get_ports(Listener.CONTROL))
+
+  def test_get_listeners(self):
+    """
+    Test Controller.get_listeners against a running tor instance.
+    """
+
+    if test.runner.require_control(self):
+      return
+
+    runner = test.runner.get_runner()
+
+    with runner.get_tor_controller() as controller:
+      self.assertEqual([], controller.get_listeners(Listener.OR))
+      self.assertEqual([], controller.get_listeners(Listener.DIR))
+      self.assertEqual([('127.0.0.1', test.runner.SOCKS_PORT)], controller.get_listeners(Listener.SOCKS))
+      self.assertEqual([], controller.get_listeners(Listener.TRANS))
+      self.assertEqual([], controller.get_listeners(Listener.NATD))
+      self.assertEqual([], controller.get_listeners(Listener.DNS))
+
+      if test.runner.Torrc.PORT in runner.get_options():
+        self.assertEqual([('127.0.0.1', test.runner.CONTROL_PORT)], controller.get_listeners(Listener.CONTROL))
+      else:
+        self.assertEqual([], controller.get_listeners(Listener.CONTROL))
+
+  def test_get_socks_listeners(self):
+    """
+    Test Controller.get_socks_listeners against a running tor instance.
     """
 
     if test.runner.require_control(self):
@@ -617,10 +663,10 @@ class TestController(unittest.TestCase):
     runner = test.runner.get_runner()
 
     with runner.get_tor_controller() as controller:
-      if not test.runner.require_version(self, stem.version.Version("0.1.2.2-alpha")):
-        controller.enable_feature("VERBOSE_NAMES")
+      if not test.runner.require_version(self, stem.version.Version('0.1.2.2-alpha')):
+        controller.enable_feature('VERBOSE_NAMES')
 
-      self.assertTrue(controller.is_feature_enabled("VERBOSE_NAMES"))
+      self.assertTrue(controller.is_feature_enabled('VERBOSE_NAMES'))
 
       orconn_output = controller.get_info('orconn-status')
 
@@ -629,13 +675,13 @@ class TestController(unittest.TestCase):
         if test.runner.require_online(self):
           return
 
-      self.assertTrue("VERBOSE_NAMES" in controller._enabled_features)
-      self.assertRaises(stem.InvalidArguments, controller.enable_feature, ["NOT", "A", "FEATURE"])
+      self.assertTrue('VERBOSE_NAMES' in controller._enabled_features)
+      self.assertRaises(stem.InvalidArguments, controller.enable_feature, ['NOT', 'A', 'FEATURE'])
 
       try:
-        controller.enable_feature(["NOT", "A", "FEATURE"])
+        controller.enable_feature(['NOT', 'A', 'FEATURE'])
       except stem.InvalidArguments as exc:
-        self.assertEqual(["NOT"], exc.arguments)
+        self.assertEqual(['NOT'], exc.arguments)
       else:
         self.fail()
 
@@ -649,10 +695,27 @@ class TestController(unittest.TestCase):
 
     with test.runner.get_runner().get_tor_controller() as controller:
       # valid signal
-      controller.signal("CLEARDNSCACHE")
+      controller.signal('CLEARDNSCACHE')
 
       # invalid signals
-      self.assertRaises(stem.InvalidArguments, controller.signal, "FOOBAR")
+      self.assertRaises(stem.InvalidArguments, controller.signal, 'FOOBAR')
+
+  def test_newnym_availability(self):
+    """
+    Test the is_newnym_available and get_newnym_wait methods.
+    """
+
+    if test.runner.require_control(self):
+      return
+
+    with test.runner.get_runner().get_tor_controller() as controller:
+      self.assertEqual(True, controller.is_newnym_available())
+      self.assertEqual(0.0, controller.get_newnym_wait())
+
+      controller.signal(stem.Signal.NEWNYM)
+
+      self.assertEqual(False, controller.is_newnym_available())
+      self.assertTrue(controller.get_newnym_wait() > 9.0)
 
   def test_extendcircuit(self):
     if test.runner.require_control(self):
@@ -670,9 +733,9 @@ class TestController(unittest.TestCase):
       circuit_id = controller.new_circuit()
       self.assertNotEqual(None, controller.get_circuit(circuit_id, None))
 
-      self.assertRaises(stem.InvalidRequest, controller.extend_circuit, "foo")
-      self.assertRaises(stem.InvalidRequest, controller.extend_circuit, '0', "thisroutershouldntexistbecausestemexists!@##$%#")
-      self.assertRaises(stem.InvalidRequest, controller.extend_circuit, '0', "thisroutershouldntexistbecausestemexists!@##$%#", "foo")
+      self.assertRaises(stem.InvalidRequest, controller.extend_circuit, 'foo')
+      self.assertRaises(stem.InvalidRequest, controller.extend_circuit, '0', 'thisroutershouldntexistbecausestemexists!@##$%#')
+      self.assertRaises(stem.InvalidRequest, controller.extend_circuit, '0', 'thisroutershouldntexistbecausestemexists!@##$%#', 'foo')
 
   def test_repurpose_circuit(self):
     """
@@ -690,16 +753,16 @@ class TestController(unittest.TestCase):
 
     with runner.get_tor_controller() as controller:
       circ_id = controller.new_circuit()
-      controller.repurpose_circuit(circ_id, "CONTROLLER")
+      controller.repurpose_circuit(circ_id, 'CONTROLLER')
       circuit = controller.get_circuit(circ_id)
-      self.assertTrue(circuit.purpose == "CONTROLLER")
+      self.assertTrue(circuit.purpose == 'CONTROLLER')
 
-      controller.repurpose_circuit(circ_id, "GENERAL")
+      controller.repurpose_circuit(circ_id, 'GENERAL')
       circuit = controller.get_circuit(circ_id)
-      self.assertTrue(circuit.purpose == "GENERAL")
+      self.assertTrue(circuit.purpose == 'GENERAL')
 
-      self.assertRaises(stem.InvalidRequest, controller.repurpose_circuit, 'f934h9f3h4', "fooo")
-      self.assertRaises(stem.InvalidRequest, controller.repurpose_circuit, '4', "fooo")
+      self.assertRaises(stem.InvalidRequest, controller.repurpose_circuit, 'f934h9f3h4', 'fooo')
+      self.assertRaises(stem.InvalidRequest, controller.repurpose_circuit, '4', 'fooo')
 
   def test_close_circuit(self):
     """
@@ -718,19 +781,19 @@ class TestController(unittest.TestCase):
     with runner.get_tor_controller() as controller:
       circuit_id = controller.new_circuit()
       controller.close_circuit(circuit_id)
-      circuit_output = controller.get_info("circuit-status")
+      circuit_output = controller.get_info('circuit-status')
       circ = [x.split()[0] for x in circuit_output.splitlines()]
       self.assertFalse(circuit_id in circ)
 
       circuit_id = controller.new_circuit()
-      controller.close_circuit(circuit_id, "IfUnused")
-      circuit_output = controller.get_info("circuit-status")
+      controller.close_circuit(circuit_id, 'IfUnused')
+      circuit_output = controller.get_info('circuit-status')
       circ = [x.split()[0] for x in circuit_output.splitlines()]
       self.assertFalse(circuit_id in circ)
 
       circuit_id = controller.new_circuit()
-      self.assertRaises(stem.InvalidArguments, controller.close_circuit, circuit_id + "1024")
-      self.assertRaises(stem.InvalidRequest, controller.close_circuit, "")
+      self.assertRaises(stem.InvalidArguments, controller.close_circuit, circuit_id + '1024')
+      self.assertRaises(stem.InvalidRequest, controller.close_circuit, '')
 
   def test_get_streams(self):
     """
@@ -742,7 +805,7 @@ class TestController(unittest.TestCase):
     elif test.runner.require_online(self):
       return
 
-    host = "38.229.72.14"   # www.torproject.org
+    host = '38.229.72.14'   # www.torproject.org
     port = 443
 
     runner = test.runner.get_runner()
@@ -758,7 +821,7 @@ class TestController(unittest.TestCase):
     # Because we do not get a stream id when opening a stream,
     #  try to match the target for which we asked a stream.
 
-    self.assertTrue("%s:%s" % (host, port) in [stream.target for stream in streams])
+    self.assertTrue('%s:%s' % (host, port) in [stream.target for stream in streams])
 
   def test_close_stream(self):
     """
@@ -774,22 +837,33 @@ class TestController(unittest.TestCase):
 
     with runner.get_tor_controller() as controller:
       # use the first socks listener
+
       socks_listener = controller.get_socks_listeners()[0]
+
       with test.network.Socks(socks_listener) as s:
         s.settimeout(30)
-        s.connect(("www.torproject.org", 443))
+        s.connect(('www.torproject.org', 443))
+
         # There's only one stream right now.  Right?
+
         built_stream = controller.get_streams()[0]
+
         # Make sure we have the stream for which we asked, otherwise
         # the next assertion would be a false positive.
+
         self.assertEqual([built_stream.id], [stream.id for stream in controller.get_streams()])
+
         # Try to close our stream...
+
         controller.close_stream(built_stream.id)
+
         # ...which means there are zero streams.
+
         self.assertEqual([], controller.get_streams())
 
       # unknown stream
-      self.assertRaises(stem.InvalidArguments, controller.close_stream, "blarg")
+
+      self.assertRaises(stem.InvalidArguments, controller.close_stream, 'blarg')
 
   def test_mapaddress(self):
     if test.runner.require_control(self):
@@ -806,6 +880,7 @@ class TestController(unittest.TestCase):
       response = None
 
       # try up to 10 times to rule out transient network failures
+
       for _ in xrange(10):
         try:
           s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -827,8 +902,8 @@ class TestController(unittest.TestCase):
 
       # everything after the blank line is the 'data' in a HTTP response.
       # The response data for our request for request should be an IP address + '\n'
-      ip_addr = response[response.find(b"\r\n\r\n"):].strip()
 
+      ip_addr = response[response.find(b'\r\n\r\n'):].strip()
       self.assertTrue(stem.util.connection.is_valid_ipv4_address(stem.util.str_tools._to_unicode(ip_addr)))
 
   def test_get_microdescriptor(self):
@@ -844,13 +919,13 @@ class TestController(unittest.TestCase):
     with test.runner.get_runner().get_tor_controller() as controller:
       # we should balk at invalid content
       self.assertRaises(ValueError, controller.get_microdescriptor, None)
-      self.assertRaises(ValueError, controller.get_microdescriptor, "")
+      self.assertRaises(ValueError, controller.get_microdescriptor, '')
       self.assertRaises(ValueError, controller.get_microdescriptor, 5)
-      self.assertRaises(ValueError, controller.get_microdescriptor, "z" * 30)
+      self.assertRaises(ValueError, controller.get_microdescriptor, 'z' * 30)
 
       # try with a relay that doesn't exist
-      self.assertRaises(stem.ControllerError, controller.get_microdescriptor, "blargg")
-      self.assertRaises(stem.ControllerError, controller.get_microdescriptor, "5" * 40)
+      self.assertRaises(stem.ControllerError, controller.get_microdescriptor, 'blargg')
+      self.assertRaises(stem.ControllerError, controller.get_microdescriptor, '5' * 40)
 
       test_relay = self._get_router_status_entry(controller)
 
@@ -868,8 +943,8 @@ class TestController(unittest.TestCase):
 
     if test.runner.require_control(self):
       return
-    elif not os.path.exists(runner.get_test_dir("cached-descriptors")):
-      test.runner.skip(self, "(no cached microdescriptors)")
+    elif not os.path.exists(runner.get_test_dir('cached-descriptors')):
+      test.runner.skip(self, '(no cached microdescriptors)')
       return
 
     with runner.get_tor_controller() as controller:
@@ -892,19 +967,19 @@ class TestController(unittest.TestCase):
     if test.runner.require_control(self):
       return
     elif runner.get_tor_version() >= Requirement.MICRODESCRIPTOR_IS_DEFAULT:
-      test.runner.skip(self, "(requires server descriptors)")
+      test.runner.skip(self, '(requires server descriptors)')
       return
 
     with runner.get_tor_controller() as controller:
       # we should balk at invalid content
       self.assertRaises(ValueError, controller.get_server_descriptor, None)
-      self.assertRaises(ValueError, controller.get_server_descriptor, "")
+      self.assertRaises(ValueError, controller.get_server_descriptor, '')
       self.assertRaises(ValueError, controller.get_server_descriptor, 5)
-      self.assertRaises(ValueError, controller.get_server_descriptor, "z" * 30)
+      self.assertRaises(ValueError, controller.get_server_descriptor, 'z' * 30)
 
       # try with a relay that doesn't exist
-      self.assertRaises(stem.ControllerError, controller.get_server_descriptor, "blargg")
-      self.assertRaises(stem.ControllerError, controller.get_server_descriptor, "5" * 40)
+      self.assertRaises(stem.ControllerError, controller.get_server_descriptor, 'blargg')
+      self.assertRaises(stem.ControllerError, controller.get_server_descriptor, '5' * 40)
 
       test_relay = self._get_router_status_entry(controller)
 
@@ -923,7 +998,7 @@ class TestController(unittest.TestCase):
     if test.runner.require_control(self):
       return
     elif runner.get_tor_version() >= Requirement.MICRODESCRIPTOR_IS_DEFAULT:
-      test.runner.skip(self, "(requires server descriptors)")
+      test.runner.skip(self, '(requires server descriptors)')
       return
 
     with runner.get_tor_controller() as controller:
@@ -952,13 +1027,13 @@ class TestController(unittest.TestCase):
     with test.runner.get_runner().get_tor_controller() as controller:
       # we should balk at invalid content
       self.assertRaises(ValueError, controller.get_network_status, None)
-      self.assertRaises(ValueError, controller.get_network_status, "")
+      self.assertRaises(ValueError, controller.get_network_status, '')
       self.assertRaises(ValueError, controller.get_network_status, 5)
-      self.assertRaises(ValueError, controller.get_network_status, "z" * 30)
+      self.assertRaises(ValueError, controller.get_network_status, 'z' * 30)
 
       # try with a relay that doesn't exist
-      self.assertRaises(stem.ControllerError, controller.get_network_status, "blargg")
-      self.assertRaises(stem.ControllerError, controller.get_network_status, "5" * 40)
+      self.assertRaises(stem.ControllerError, controller.get_network_status, 'blargg')
+      self.assertRaises(stem.ControllerError, controller.get_network_status, '5' * 40)
 
       test_relay = self._get_router_status_entry(controller)
 
@@ -987,7 +1062,7 @@ class TestController(unittest.TestCase):
         unrecognized_lines = desc.get_unrecognized_lines()
 
         if unrecognized_lines:
-          self.fail("Unrecognized descriptor content: %s" % unrecognized_lines)
+          self.fail('Unrecognized descriptor content: %s' % unrecognized_lines)
 
         count += 1
         if count > 10:
@@ -1001,20 +1076,20 @@ class TestController(unittest.TestCase):
     elif test.runner.require_version(self, Requirement.EXTENDCIRCUIT_PATH_OPTIONAL):
       return
 
-    host = "38.229.72.14"   # www.torproject.org
+    host = '38.229.72.14'   # www.torproject.org
     port = 80
 
     circuit_id = None
 
     def handle_streamcreated(stream):
-      if stream.status == "NEW" and circuit_id:
+      if stream.status == 'NEW' and circuit_id:
         controller.attach_stream(stream.id, circuit_id)
 
     with test.runner.get_runner().get_tor_controller() as controller:
       # try 10 times to build a circuit we can connect through
       for i in xrange(10):
         controller.add_event_listener(handle_streamcreated, stem.control.EventType.STREAM)
-        controller.set_conf("__LeaveStreamsUnattached", "1")
+        controller.set_conf('__LeaveStreamsUnattached', '1')
 
         try:
           circuit_id = controller.new_circuit(await_build = True)
@@ -1029,7 +1104,7 @@ class TestController(unittest.TestCase):
           continue
         finally:
           controller.remove_event_listener(handle_streamcreated)
-          controller.reset_conf("__LeaveStreamsUnattached")
+          controller.reset_conf('__LeaveStreamsUnattached')
 
     our_stream = [stream for stream in streams if stream.target_address == host][0]
 
@@ -1066,13 +1141,13 @@ class TestController(unittest.TestCase):
 
     if TEST_ROUTER_STATUS_ENTRY is None:
       for desc in controller.get_network_statuses():
-        if desc.nickname != "Unnamed" and Flag.NAMED in desc.flags:
+        if desc.nickname != 'Unnamed' and Flag.NAMED in desc.flags:
           TEST_ROUTER_STATUS_ENTRY = desc
           break
 
       if TEST_ROUTER_STATUS_ENTRY is None:
         # this is only likely to occure if we can't get descriptors
-        test.runner.skip(self, "(no named relays)")
+        test.runner.skip(self, '(no named relays)')
         return
 
     return TEST_ROUTER_STATUS_ENTRY
