@@ -23,24 +23,24 @@ class TestNetworkStatus(unittest.TestCase):
 
     # lengthy test and uneffected by targets, so only run once
 
-    if test.runner.only_run_once(self, "test_cached_consensus"):
+    if test.runner.only_run_once(self, 'test_cached_consensus'):
       return
 
-    consensus_path = test.runner.get_runner().get_test_dir("cached-consensus")
+    consensus_path = test.runner.get_runner().get_test_dir('cached-consensus')
 
     if not os.path.exists(consensus_path):
-      test.runner.skip(self, "(no cached-consensus)")
+      test.runner.skip(self, '(no cached-consensus)')
       return
     elif stem.util.system.is_windows():
       # Unable to check memory usage on windows, so can't prevent hanging the
       # system if things go bad.
 
-      test.runner.skip(self, "(unavailable on windows)")
+      test.runner.skip(self, '(unavailable on windows)')
       return
 
     count = 0
     with open(consensus_path, 'rb') as descriptor_file:
-      for router in stem.descriptor.parse_file(descriptor_file, "network-status-consensus-3 1.0"):
+      for router in stem.descriptor.parse_file(descriptor_file, 'network-status-consensus-3 1.0'):
         count += 1
 
         # check if there's any unknown flags
@@ -48,12 +48,12 @@ class TestNetworkStatus(unittest.TestCase):
         # failing the tests
         for flag in router.flags:
           if not flag in stem.Flag:
-            raise ValueError("Unrecognized flag type: %s, found on relay %s (%s)" % (flag, router.fingerprint, router.nickname))
+            raise ValueError('Unrecognized flag type: %s, found on relay %s (%s)' % (flag, router.fingerprint, router.nickname))
 
         unrecognized_lines = router.get_unrecognized_lines()
 
         if unrecognized_lines:
-          self.fail("Unrecognized descriptor content: %s" % unrecognized_lines)
+          self.fail('Unrecognized descriptor content: %s' % unrecognized_lines)
 
     # Sanity test that there's at least a hundred relays. If that's not the
     # case then this probably isn't a real, complete tor consensus.
@@ -67,21 +67,21 @@ class TestNetworkStatus(unittest.TestCase):
 
     # lengthy test and uneffected by targets, so only run once
 
-    if test.runner.only_run_once(self, "test_cached_microdesc_consensus"):
+    if test.runner.only_run_once(self, 'test_cached_microdesc_consensus'):
       return
 
-    consensus_path = test.runner.get_runner().get_test_dir("cached-microdesc-consensus")
+    consensus_path = test.runner.get_runner().get_test_dir('cached-microdesc-consensus')
 
     if not os.path.exists(consensus_path):
-      test.runner.skip(self, "(no cached-microdesc-consensus)")
+      test.runner.skip(self, '(no cached-microdesc-consensus)')
       return
     elif stem.util.system.is_windows():
-      test.runner.skip(self, "(unavailable on windows)")
+      test.runner.skip(self, '(unavailable on windows)')
       return
 
     count = 0
     with open(consensus_path, 'rb') as descriptor_file:
-      for router in stem.descriptor.parse_file(descriptor_file, "network-status-microdesc-consensus-3 1.0"):
+      for router in stem.descriptor.parse_file(descriptor_file, 'network-status-microdesc-consensus-3 1.0'):
         count += 1
 
         # check if there's any unknown flags
@@ -89,12 +89,12 @@ class TestNetworkStatus(unittest.TestCase):
         # failing the tests
         for flag in router.flags:
           if not flag in stem.Flag:
-            raise ValueError("Unrecognized flag type: %s, found on microdescriptor relay %s (%s)" % (flag, router.fingerprint, router.nickname))
+            raise ValueError('Unrecognized flag type: %s, found on microdescriptor relay %s (%s)' % (flag, router.fingerprint, router.nickname))
 
         unrecognized_lines = router.get_unrecognized_lines()
 
         if unrecognized_lines:
-          self.fail("Unrecognized descriptor content: %s" % unrecognized_lines)
+          self.fail('Unrecognized descriptor content: %s' % unrecognized_lines)
 
     self.assertTrue(count > 100)
 
@@ -103,21 +103,21 @@ class TestNetworkStatus(unittest.TestCase):
     Checks if consensus documents from Metrics are parsed properly.
     """
 
-    consensus_path = get_resource("metrics_consensus")
+    consensus_path = get_resource('metrics_consensus')
 
     for specify_type in (True, False):
       with open(consensus_path, 'rb') as descriptor_file:
         if specify_type:
-          descriptors = stem.descriptor.parse_file(descriptor_file, "network-status-consensus-3 1.0")
+          descriptors = stem.descriptor.parse_file(descriptor_file, 'network-status-consensus-3 1.0')
         else:
           descriptors = stem.descriptor.parse_file(descriptor_file)
 
         router = next(descriptors)
-        self.assertEquals("sumkledi", router.nickname)
-        self.assertEquals("0013D22389CD50D0B784A3E4061CB31E8CE8CEB5", router.fingerprint)
-        self.assertEquals("F260ABF1297B445E04354E236F4159140FF7768F", router.digest)
+        self.assertEquals('sumkledi', router.nickname)
+        self.assertEquals('0013D22389CD50D0B784A3E4061CB31E8CE8CEB5', router.fingerprint)
+        self.assertEquals('F260ABF1297B445E04354E236F4159140FF7768F', router.digest)
         self.assertEquals(datetime.datetime(2012, 7, 12, 4, 1, 55), router.published)
-        self.assertEquals("178.218.213.229", router.address)
+        self.assertEquals('178.218.213.229', router.address)
         self.assertEquals(80, router.or_port)
         self.assertEquals(None, router.dir_port)
 
@@ -126,15 +126,15 @@ class TestNetworkStatus(unittest.TestCase):
     Checks if the bridge documents from Metrics are parsed properly.
     """
 
-    consensus_path = get_resource("bridge_network_status")
+    consensus_path = get_resource('bridge_network_status')
 
     with open(consensus_path, 'rb') as descriptor_file:
       router = next(stem.descriptor.parse_file(descriptor_file))
-      self.assertEquals("Unnamed", router.nickname)
-      self.assertEquals("0014A2055278DB3EB0E59EA701741416AF185558", router.fingerprint)
-      self.assertEquals("148EF8685B8D259650AE0967D1FF8E6A870C7743", router.digest)
+      self.assertEquals('Unnamed', router.nickname)
+      self.assertEquals('0014A2055278DB3EB0E59EA701741416AF185558', router.fingerprint)
+      self.assertEquals('148EF8685B8D259650AE0967D1FF8E6A870C7743', router.digest)
       self.assertEquals(datetime.datetime(2012, 5, 31, 15, 57, 0), router.published)
-      self.assertEquals("10.97.236.247", router.address)
+      self.assertEquals('10.97.236.247', router.address)
       self.assertEquals(443, router.or_port)
       self.assertEquals(None, router.dir_port)
 
@@ -172,14 +172,14 @@ RY22NXCwrJvSMEwiy7acC8FGysqwHRyE356+Rw6TB43g3Tno9KaHEK7MHXjSHwNs
 GM9hAsAMRX9Ogqhq5UjDNqEsvDKuyVeyh7unSZEOip9Zr6K/+7VsVPNb8vfBRBjo
 -----END SIGNATURE-----"""
 
-    cert_path = get_resource("metrics_cert")
+    cert_path = get_resource('metrics_cert')
 
     with open(cert_path, 'rb') as cert_file:
       cert = next(stem.descriptor.parse_file(cert_file))
       self.assertEquals(3, cert.version)
       self.assertEquals(None, cert.address)
       self.assertEquals(None, cert.dir_port)
-      self.assertEquals("14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4", cert.fingerprint)
+      self.assertEquals('14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4', cert.fingerprint)
       self.assertEquals(expected_identity_key, cert.identity_key)
       self.assertEquals(datetime.datetime(2008, 5, 9, 21, 13, 26), cert.published)
       self.assertEquals(datetime.datetime(2009, 5, 9, 21, 13, 26), cert.expires)
@@ -195,30 +195,30 @@ GM9hAsAMRX9Ogqhq5UjDNqEsvDKuyVeyh7unSZEOip9Zr6K/+7VsVPNb8vfBRBjo
 
     # the document's expected client and server versions are the same
     expected_versions = [stem.version.Version(v) for v in (
-      "0.2.2.35",
-      "0.2.2.36",
-      "0.2.2.37",
-      "0.2.3.10-alpha",
-      "0.2.3.11-alpha",
-      "0.2.3.12-alpha",
-      "0.2.3.13-alpha",
-      "0.2.3.14-alpha",
-      "0.2.3.15-alpha",
-      "0.2.3.16-alpha",
-      "0.2.3.17-beta",
-      "0.2.3.18-rc",
-      "0.2.3.19-rc",
+      '0.2.2.35',
+      '0.2.2.36',
+      '0.2.2.37',
+      '0.2.3.10-alpha',
+      '0.2.3.11-alpha',
+      '0.2.3.12-alpha',
+      '0.2.3.13-alpha',
+      '0.2.3.14-alpha',
+      '0.2.3.15-alpha',
+      '0.2.3.16-alpha',
+      '0.2.3.17-beta',
+      '0.2.3.18-rc',
+      '0.2.3.19-rc',
     )]
 
     expected_flags = set(
-      ["Authority", "BadExit", "Exit", "Fast", "Guard", "HSDir",
-       "Named", "Running", "Stable", "Unnamed", "V2Dir", "Valid"])
+      ['Authority', 'BadExit', 'Exit', 'Fast', 'Guard', 'HSDir',
+       'Named', 'Running', 'Stable', 'Unnamed', 'V2Dir', 'Valid'])
 
     expected_bandwidth_weights = {
-      "Wbd": 3335, "Wbe": 0, "Wbg": 3536, "Wbm": 10000, "Wdb": 10000,
-      "Web": 10000, "Wed": 3329, "Wee": 10000, "Weg": 3329, "Wem": 10000,
-      "Wgb": 10000, "Wgd": 3335, "Wgg": 6464, "Wgm": 6464, "Wmb": 10000,
-      "Wmd": 3335, "Wme": 0, "Wmg": 3536, "Wmm": 10000
+      'Wbd': 3335, 'Wbe': 0, 'Wbg': 3536, 'Wbm': 10000, 'Wdb': 10000,
+      'Web': 10000, 'Wed': 3329, 'Wee': 10000, 'Weg': 3329, 'Wem': 10000,
+      'Wgb': 10000, 'Wgd': 3335, 'Wgg': 6464, 'Wgm': 6464, 'Wmb': 10000,
+      'Wmd': 3335, 'Wme': 0, 'Wmg': 3536, 'Wmm': 10000
     }
 
     expected_signature = """-----BEGIN SIGNATURE-----
@@ -227,7 +227,7 @@ mfWcW0b+jsrXcJoCxV5IrwCDF3u1aC3diwZY6yiG186pwWbOwE41188XI2DeYPwE
 I/TJmV928na7RLZe2mGHCAW3VQOvV+QkCfj05VZ8CsY=
 -----END SIGNATURE-----"""
 
-    with open(get_resource("cached-consensus"), 'rb') as descriptor_file:
+    with open(get_resource('cached-consensus'), 'rb') as descriptor_file:
       document = stem.descriptor.networkstatus.NetworkStatusDocumentV3(descriptor_file.read(), default_params = False)
 
       self.assertEquals(3, document.version)
@@ -243,7 +243,7 @@ I/TJmV928na7RLZe2mGHCAW3VQOvV+QkCfj05VZ8CsY=
       self.assertEquals(expected_versions, document.client_versions)
       self.assertEquals(expected_versions, document.server_versions)
       self.assertEquals(expected_flags, set(document.known_flags))
-      self.assertEquals({"CircuitPriorityHalflifeMsec": 30000, "bwauthpid": 1}, document.params)
+      self.assertEquals({'CircuitPriorityHalflifeMsec': 30000, 'bwauthpid': 1}, document.params)
 
       self.assertEquals(12, document.consensus_method)
       self.assertEquals(expected_bandwidth_weights, document.bandwidth_weights)
@@ -251,34 +251,34 @@ I/TJmV928na7RLZe2mGHCAW3VQOvV+QkCfj05VZ8CsY=
       self.assertEquals(None, document.published)
       self.assertEquals([], document.get_unrecognized_lines())
 
-      router = document.routers["0013D22389CD50D0B784A3E4061CB31E8CE8CEB5"]
-      self.assertEquals("sumkledi", router.nickname)
-      self.assertEquals("0013D22389CD50D0B784A3E4061CB31E8CE8CEB5", router.fingerprint)
-      self.assertEquals("F260ABF1297B445E04354E236F4159140FF7768F", router.digest)
+      router = document.routers['0013D22389CD50D0B784A3E4061CB31E8CE8CEB5']
+      self.assertEquals('sumkledi', router.nickname)
+      self.assertEquals('0013D22389CD50D0B784A3E4061CB31E8CE8CEB5', router.fingerprint)
+      self.assertEquals('F260ABF1297B445E04354E236F4159140FF7768F', router.digest)
       self.assertEquals(datetime.datetime(2012, 7, 12, 4, 1, 55), router.published)
-      self.assertEquals("178.218.213.229", router.address)
+      self.assertEquals('178.218.213.229', router.address)
       self.assertEquals(80, router.or_port)
       self.assertEquals(None, router.dir_port)
-      self.assertEquals(set(["Exit", "Fast", "Named", "Running", "Valid"]), set(router.flags))
+      self.assertEquals(set(['Exit', 'Fast', 'Named', 'Running', 'Valid']), set(router.flags))
 
       authority = document.directory_authorities[0]
       self.assertEquals(8, len(document.directory_authorities))
-      self.assertEquals("tor26", authority.nickname)
-      self.assertEquals("14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4", authority.fingerprint)
-      self.assertEquals("86.59.21.38", authority.hostname)
-      self.assertEquals("86.59.21.38", authority.address)
+      self.assertEquals('tor26', authority.nickname)
+      self.assertEquals('14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4', authority.fingerprint)
+      self.assertEquals('86.59.21.38', authority.hostname)
+      self.assertEquals('86.59.21.38', authority.address)
       self.assertEquals(80, authority.dir_port)
       self.assertEquals(443, authority.or_port)
-      self.assertEquals("Peter Palfrader", authority.contact)
-      self.assertEquals("0B6D1E9A300B895AA2D0B427F92917B6995C3C1C", authority.vote_digest)
+      self.assertEquals('Peter Palfrader', authority.contact)
+      self.assertEquals('0B6D1E9A300B895AA2D0B427F92917B6995C3C1C', authority.vote_digest)
       self.assertEquals(None, authority.legacy_dir_key)
       self.assertEquals(None, authority.key_certificate)
 
       signature = document.signatures[0]
       self.assertEquals(8, len(document.signatures))
-      self.assertEquals("sha1", signature.method)
-      self.assertEquals("14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4", signature.identity)
-      self.assertEquals("BF112F1C6D5543CFD0A32215ACABD4197B5279AD", signature.key_digest)
+      self.assertEquals('sha1', signature.method)
+      self.assertEquals('14C131DFC5C6F93646BE72FA1401C02A8DF2E8B4', signature.identity)
+      self.assertEquals('BF112F1C6D5543CFD0A32215ACABD4197B5279AD', signature.key_digest)
       self.assertEquals(expected_signature, signature.signature)
 
   def test_consensus_v2(self):
@@ -298,80 +298,80 @@ nTA+fD8JQqpPtb8b0SnG9kwy75eS//sRu7TErie2PzGMxrf9LH0LAgMBAAE=
 TpQQk3nNQF8z6UIvdlvP+DnJV4izWVkQEZgUZgIVM0E=
 -----END SIGNATURE-----"""
 
-    with open(get_resource("cached-consensus-v2"), 'rb') as descriptor_file:
+    with open(get_resource('cached-consensus-v2'), 'rb') as descriptor_file:
       descriptor_file.readline()  # strip header
       document = stem.descriptor.networkstatus.NetworkStatusDocumentV2(descriptor_file.read())
 
       self.assertEquals(2, document.version)
-      self.assertEquals("18.244.0.114", document.hostname)
-      self.assertEquals("18.244.0.114", document.address)
+      self.assertEquals('18.244.0.114', document.hostname)
+      self.assertEquals('18.244.0.114', document.address)
       self.assertEquals(80, document.dir_port)
-      self.assertEquals("719BE45DE224B607C53707D0E2143E2D423E74CF", document.fingerprint)
-      self.assertEquals("arma at mit dot edu", document.contact)
+      self.assertEquals('719BE45DE224B607C53707D0E2143E2D423E74CF', document.fingerprint)
+      self.assertEquals('arma at mit dot edu', document.contact)
       self.assertEquals(expected_signing_key, document.signing_key)
 
       self.assertEquals(67, len(document.client_versions))
-      self.assertEquals("0.0.9rc2", document.client_versions[0])
-      self.assertEquals("0.1.1.10-alpha-cvs", document.client_versions[-1])
+      self.assertEquals('0.0.9rc2', document.client_versions[0])
+      self.assertEquals('0.1.1.10-alpha-cvs', document.client_versions[-1])
 
       self.assertEquals(67, len(document.server_versions))
-      self.assertEquals("0.0.9rc2", document.server_versions[0])
-      self.assertEquals("0.1.1.10-alpha-cvs", document.server_versions[-1])
+      self.assertEquals('0.0.9rc2', document.server_versions[0])
+      self.assertEquals('0.1.1.10-alpha-cvs', document.server_versions[-1])
 
       self.assertEquals(datetime.datetime(2005, 12, 16, 0, 13, 46), document.published)
-      self.assertEquals(["Names", "Versions"], document.options)
-      self.assertEquals("moria2", document.signing_authority)
+      self.assertEquals(['Names', 'Versions'], document.options)
+      self.assertEquals('moria2', document.signing_authority)
       self.assertEquals(expected_signature, document.signature)
       self.assertEquals([], document.get_unrecognized_lines())
 
       self.assertEqual(3, len(document.routers))
 
-      router1 = document.routers["719BE45DE224B607C53707D0E2143E2D423E74CF"]
-      self.assertEquals("moria2", router1.nickname)
-      self.assertEquals("719BE45DE224B607C53707D0E2143E2D423E74CF", router1.fingerprint)
-      self.assertEquals("B7F3F0975B87889DD1285FD57A1B1BB617F65432", router1.digest)
+      router1 = document.routers['719BE45DE224B607C53707D0E2143E2D423E74CF']
+      self.assertEquals('moria2', router1.nickname)
+      self.assertEquals('719BE45DE224B607C53707D0E2143E2D423E74CF', router1.fingerprint)
+      self.assertEquals('B7F3F0975B87889DD1285FD57A1B1BB617F65432', router1.digest)
       self.assertEquals(datetime.datetime(2005, 12, 15, 6, 57, 18), router1.published)
-      self.assertEquals("18.244.0.114", router1.address)
+      self.assertEquals('18.244.0.114', router1.address)
       self.assertEquals(443, router1.or_port)
       self.assertEquals(80, router1.dir_port)
-      self.assertEquals(set(["Authority", "Fast", "Named", "Running", "Valid", "V2Dir"]), set(router1.flags))
+      self.assertEquals(set(['Authority', 'Fast', 'Named', 'Running', 'Valid', 'V2Dir']), set(router1.flags))
 
-      router2 = document.routers["0928BA467056C4A689FEE4EF5D71482B6289C3D5"]
-      self.assertEquals("stnv", router2.nickname)
-      self.assertEquals("0928BA467056C4A689FEE4EF5D71482B6289C3D5", router2.fingerprint)
-      self.assertEquals("22D1A7ED4199BDA7ED6C416EECD769C18E1F2A5A", router2.digest)
+      router2 = document.routers['0928BA467056C4A689FEE4EF5D71482B6289C3D5']
+      self.assertEquals('stnv', router2.nickname)
+      self.assertEquals('0928BA467056C4A689FEE4EF5D71482B6289C3D5', router2.fingerprint)
+      self.assertEquals('22D1A7ED4199BDA7ED6C416EECD769C18E1F2A5A', router2.digest)
       self.assertEquals(datetime.datetime(2005, 12, 15, 16, 24, 42), router2.published)
-      self.assertEquals("84.16.236.173", router2.address)
+      self.assertEquals('84.16.236.173', router2.address)
       self.assertEquals(9001, router2.or_port)
       self.assertEquals(None, router2.dir_port)
-      self.assertEquals(set(["Named", "Valid"]), set(router2.flags))
+      self.assertEquals(set(['Named', 'Valid']), set(router2.flags))
 
-      router3 = document.routers["09E8582FF0E6F85E2B8E41C0DC0B9C9DC46E6968"]
-      self.assertEquals("nggrplz", router3.nickname)
-      self.assertEquals("09E8582FF0E6F85E2B8E41C0DC0B9C9DC46E6968", router3.fingerprint)
-      self.assertEquals("B302C2B01C94F398E3EF38939526B0651F824DD6", router3.digest)
+      router3 = document.routers['09E8582FF0E6F85E2B8E41C0DC0B9C9DC46E6968']
+      self.assertEquals('nggrplz', router3.nickname)
+      self.assertEquals('09E8582FF0E6F85E2B8E41C0DC0B9C9DC46E6968', router3.fingerprint)
+      self.assertEquals('B302C2B01C94F398E3EF38939526B0651F824DD6', router3.digest)
       self.assertEquals(datetime.datetime(2005, 12, 15, 23, 25, 50), router3.published)
-      self.assertEquals("194.109.109.109", router3.address)
+      self.assertEquals('194.109.109.109', router3.address)
       self.assertEquals(9001, router3.or_port)
       self.assertEquals(None, router3.dir_port)
-      self.assertEquals(set(["Fast", "Stable", "Running", "Valid"]), set(router3.flags))
+      self.assertEquals(set(['Fast', 'Stable', 'Running', 'Valid']), set(router3.flags))
 
   def test_metrics_vote(self):
     """
     Checks if vote documents from Metrics are parsed properly.
     """
 
-    vote_path = get_resource("metrics_vote")
+    vote_path = get_resource('metrics_vote')
 
     with open(vote_path, 'rb') as descriptor_file:
       descriptors = stem.descriptor.parse_file(descriptor_file)
 
       router = next(descriptors)
-      self.assertEquals("sumkledi", router.nickname)
-      self.assertEquals("0013D22389CD50D0B784A3E4061CB31E8CE8CEB5", router.fingerprint)
-      self.assertEquals("0799F806200B005F01E40A9A7F1A21C988AE8FB1", router.digest)
+      self.assertEquals('sumkledi', router.nickname)
+      self.assertEquals('0013D22389CD50D0B784A3E4061CB31E8CE8CEB5', router.fingerprint)
+      self.assertEquals('0799F806200B005F01E40A9A7F1A21C988AE8FB1', router.digest)
       self.assertEquals(datetime.datetime(2012, 7, 11, 4, 22, 53), router.published)
-      self.assertEquals("178.218.213.229", router.address)
+      self.assertEquals('178.218.213.229', router.address)
       self.assertEquals(80, router.or_port)
       self.assertEquals(None, router.dir_port)
 
@@ -381,8 +381,8 @@ TpQQk3nNQF8z6UIvdlvP+DnJV4izWVkQEZgUZgIVM0E=
     """
 
     expected_flags = set(
-      ["Authority", "BadExit", "Exit", "Fast", "Guard", "HSDir",
-       "Running", "Stable", "V2Dir", "Valid"])
+      ['Authority', 'BadExit', 'Exit', 'Fast', 'Guard', 'HSDir',
+       'Running', 'Stable', 'V2Dir', 'Valid'])
 
     expected_identity_key = """-----BEGIN RSA PUBLIC KEY-----
 MIIBigKCAYEA6uSmsoxj2MiJ3qyZq0qYXlRoG8o82SNqg+22m+t1c7MlQOZWPJYn
@@ -425,7 +425,7 @@ JZ/1HL9sHyZfo6bwaC6YSM9PNiiY6L7rnGpS7UkHiFI+M96VCMorvjm5YPs3FioJ
 DnN5aFtYKiTc19qIC7Nmo+afPdDEf0MlJvEOP5EWl3w=
 -----END SIGNATURE-----"""
 
-    with open(get_resource("vote"), 'rb') as descriptor_file:
+    with open(get_resource('vote'), 'rb') as descriptor_file:
       document = stem.descriptor.networkstatus.NetworkStatusDocumentV3(descriptor_file.read(), default_params = False)
 
       self.assertEquals(3, document.version)
@@ -441,7 +441,7 @@ DnN5aFtYKiTc19qIC7Nmo+afPdDEf0MlJvEOP5EWl3w=
       self.assertEquals([], document.client_versions)
       self.assertEquals([], document.server_versions)
       self.assertEquals(expected_flags, set(document.known_flags))
-      self.assertEquals({"CircuitPriorityHalflifeMsec": 30000, "bwauthpid": 1}, document.params)
+      self.assertEquals({'CircuitPriorityHalflifeMsec': 30000, 'bwauthpid': 1}, document.params)
 
       self.assertEquals(None, document.consensus_method)
       self.assertEquals({}, document.bandwidth_weights)
@@ -449,24 +449,24 @@ DnN5aFtYKiTc19qIC7Nmo+afPdDEf0MlJvEOP5EWl3w=
       self.assertEquals(datetime.datetime(2012, 7, 11, 23, 50, 1), document.published)
       self.assertEquals([], document.get_unrecognized_lines())
 
-      router = document.routers["0013D22389CD50D0B784A3E4061CB31E8CE8CEB5"]
-      self.assertEquals("sumkledi", router.nickname)
-      self.assertEquals("0013D22389CD50D0B784A3E4061CB31E8CE8CEB5", router.fingerprint)
-      self.assertEquals("0799F806200B005F01E40A9A7F1A21C988AE8FB1", router.digest)
+      router = document.routers['0013D22389CD50D0B784A3E4061CB31E8CE8CEB5']
+      self.assertEquals('sumkledi', router.nickname)
+      self.assertEquals('0013D22389CD50D0B784A3E4061CB31E8CE8CEB5', router.fingerprint)
+      self.assertEquals('0799F806200B005F01E40A9A7F1A21C988AE8FB1', router.digest)
       self.assertEquals(datetime.datetime(2012, 7, 11, 4, 22, 53), router.published)
-      self.assertEquals("178.218.213.229", router.address)
+      self.assertEquals('178.218.213.229', router.address)
       self.assertEquals(80, router.or_port)
       self.assertEquals(None, router.dir_port)
 
       authority = document.directory_authorities[0]
       self.assertEquals(1, len(document.directory_authorities))
-      self.assertEquals("turtles", authority.nickname)
-      self.assertEquals("27B6B5996C426270A5C95488AA5BCEB6BCC86956", authority.fingerprint)
-      self.assertEquals("76.73.17.194", authority.hostname)
-      self.assertEquals("76.73.17.194", authority.address)
+      self.assertEquals('turtles', authority.nickname)
+      self.assertEquals('27B6B5996C426270A5C95488AA5BCEB6BCC86956', authority.fingerprint)
+      self.assertEquals('76.73.17.194', authority.hostname)
+      self.assertEquals('76.73.17.194', authority.address)
       self.assertEquals(9030, authority.dir_port)
       self.assertEquals(9090, authority.or_port)
-      self.assertEquals("Mike Perry <email>", authority.contact)
+      self.assertEquals('Mike Perry <email>', authority.contact)
       self.assertEquals(None, authority.vote_digest)
       self.assertEquals(None, authority.legacy_dir_key)
 
@@ -474,7 +474,7 @@ DnN5aFtYKiTc19qIC7Nmo+afPdDEf0MlJvEOP5EWl3w=
       self.assertEquals(3, certificate.version)
       self.assertEquals(None, certificate.address)
       self.assertEquals(None, certificate.dir_port)
-      self.assertEquals("27B6B5996C426270A5C95488AA5BCEB6BCC86956", certificate.fingerprint)
+      self.assertEquals('27B6B5996C426270A5C95488AA5BCEB6BCC86956', certificate.fingerprint)
       self.assertEquals(expected_identity_key, certificate.identity_key)
       self.assertEquals(datetime.datetime(2011, 11, 28, 21, 51, 4), certificate.published)
       self.assertEquals(datetime.datetime(2012, 11, 28, 21, 51, 4), certificate.expires)
@@ -484,7 +484,7 @@ DnN5aFtYKiTc19qIC7Nmo+afPdDEf0MlJvEOP5EWl3w=
 
       signature = document.signatures[0]
       self.assertEquals(1, len(document.signatures))
-      self.assertEquals("sha1", signature.method)
-      self.assertEquals("27B6B5996C426270A5C95488AA5BCEB6BCC86956", signature.identity)
-      self.assertEquals("D5C30C15BB3F1DA27669C2D88439939E8F418FCF", signature.key_digest)
+      self.assertEquals('sha1', signature.method)
+      self.assertEquals('27B6B5996C426270A5C95488AA5BCEB6BCC86956', signature.identity)
+      self.assertEquals('D5C30C15BB3F1DA27669C2D88439939E8F418FCF', signature.key_digest)
       self.assertEquals(expected_signature, signature.signature)
