@@ -15,10 +15,10 @@ class TestConnection(unittest.TestCase):
     runner = test.runner.get_runner()
 
     if not test.runner.Torrc.PORT in runner.get_options():
-      test.runner.skip(self, "(no control port)")
+      test.runner.skip(self, '(no control port)')
       return
     elif not test.runner.get_runner().is_ptraceable():
-      test.runner.skip(self, "(DisableDebuggerAttachment is set)")
+      test.runner.skip(self, '(DisableDebuggerAttachment is set)')
       return
 
     for resolver in get_system_resolvers():
@@ -30,4 +30,4 @@ class TestConnection(unittest.TestCase):
           if conn.local_address == '127.0.0.1' and conn.local_port == test.runner.CONTROL_PORT:
             return
 
-        self.fail("Unable to find localhost connection with %s:\n%s" % (resolver, '\n'.join(connections)))
+        self.fail('Unable to find localhost connection with %s:\n%s' % (resolver, '\n'.join(connections)))
