@@ -13,7 +13,7 @@ import stem.util.system
 import stem.version
 
 from stem import InvalidArguments, InvalidRequest, ProtocolError, UnsatisfiableRequest
-from stem.control import _parse_circ_path, Controller, EventType
+from stem.control import _parse_circ_path, Listener, Controller, EventType
 from stem.exit_policy import ExitPolicy
 from test import mocking
 
@@ -39,7 +39,7 @@ class TestControl(unittest.TestCase):
 
     try:
       # Use one version for first check.
-      version_2_1 = "0.2.1.32"
+      version_2_1 = '0.2.1.32'
       version_2_1_object = stem.version.Version(version_2_1)
       get_info_mock.return_value = version_2_1
 
@@ -47,7 +47,7 @@ class TestControl(unittest.TestCase):
       self.assertEqual(version_2_1_object, self.controller.get_version())
 
       # Use a different version for second check.
-      version_2_2 = "0.2.2.39"
+      version_2_2 = '0.2.2.39'
       version_2_2_object = stem.version.Version(version_2_2)
       get_info_mock.return_value = version_2_2
 
@@ -64,15 +64,15 @@ class TestControl(unittest.TestCase):
 
       # Get a default value when the call fails.
       self.assertEqual(
-        "default returned",
-        self.controller.get_version(default = "default returned")
+        'default returned',
+        self.controller.get_version(default = 'default returned')
       )
 
       # No default value, accept the error.
       self.assertRaises(InvalidArguments, self.controller.get_version)
 
       # Give a bad version.  The stem.version.Version ValueError should bubble up.
-      version_A_42 = "0.A.42.spam"
+      version_A_42 = '0.A.42.spam'
       get_info_mock.return_value = version_A_42
       get_info_mock.side_effect = None
       self.assertRaises(ValueError, self.controller.get_version)
@@ -88,13 +88,13 @@ class TestControl(unittest.TestCase):
     """
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "ExitPolicyRejectPrivate": "1",
-      "ExitPolicy": ["accept *:80,   accept *:443", "accept 43.5.5.5,reject *:22"],
+      'ExitPolicyRejectPrivate': '1',
+      'ExitPolicy': ['accept *:80,   accept *:443', 'accept 43.5.5.5,reject *:22'],
     }[param]
 
     get_info_mock.side_effect = lambda param, default = None: {
-      "address": "123.45.67.89",
-      "exit-policy/default": "reject *:25,reject *:119,reject *:135-139,reject *:445,reject *:563,reject *:1214,reject *:4661-4666,reject *:6346-6429,reject *:6699,reject *:6881-6999,accept *:*",
+      'address': '123.45.67.89',
+      'exit-policy/default': 'reject *:25,reject *:119,reject *:135-139,reject *:445,reject *:563,reject *:1214,reject *:4661-4666,reject *:6346-6429,reject *:6699,reject *:6881-6999,accept *:*',
     }[param]
 
     expected = ExitPolicy(
@@ -124,6 +124,55 @@ class TestControl(unittest.TestCase):
 
     self.assertEqual(expected, self.controller.get_exit_policy())
 
+  @patch('stem.control.Controller.get_info')
+  @patch('stem.control.Controller.get_conf')
+  def test_get_ports(self, get_conf_mock, get_info_mock):
+    """
+    Exercises the get_ports() and get_listeners() methods.
+    """
+
+    # Exercise as an old version of tor that doesn't support the 'GETINFO
+    # net/listeners/*' options.
+
+    get_info_mock.side_effect = InvalidArguments
+
+    get_conf_mock.side_effect = lambda param, **kwargs: {
+      'ControlPort': '9050',
+      'ControlListenAddress': ['127.0.0.1'],
+    }[param]
+
+    self.assertEqual([('127.0.0.1', 9050)], self.controller.get_listeners(Listener.CONTROL))
+    self.assertEqual([9050], self.controller.get_ports(Listener.CONTROL))
+
+    # non-local addresss
+
+    get_conf_mock.side_effect = lambda param, **kwargs: {
+      'ControlPort': '9050',
+      'ControlListenAddress': ['27.4.4.1'],
+    }[param]
+
+    self.assertEqual([('27.4.4.1', 9050)], self.controller.get_listeners(Listener.CONTROL))
+    self.assertEqual([], self.controller.get_ports(Listener.CONTROL))
+
+    # Exercise via the GETINFO option.
+
+    get_info_mock.side_effect = None
+    get_info_mock.return_value = '"127.0.0.1:1112" "127.0.0.1:1114"'
+
+    self.assertEqual(
+      [('127.0.0.1', 1112), ('127.0.0.1', 1114)],
+      self.controller.get_listeners(Listener.CONTROL)
+    )
+
+    self.assertEqual([1112, 1114], self.controller.get_ports(Listener.CONTROL))
+
+    # unix socket file
+
+    get_info_mock.return_value = '"unix:/tmp/tor/socket"'
+
+    self.assertEqual([], self.controller.get_listeners(Listener.CONTROL))
+    self.assertEqual([], self.controller.get_ports(Listener.CONTROL))
+
   @patch('stem.control.Controller.get_info')
   @patch('stem.control.Controller.get_conf')
   def test_get_socks_listeners_old(self, get_conf_mock, get_info_mock):
@@ -138,8 +187,8 @@ class TestControl(unittest.TestCase):
     get_info_mock.side_effect = InvalidArguments
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "9050",
-      "SocksListenAddress": ["127.0.0.1"],
+      'SocksPort': '9050',
+      'SocksListenAddress': ['127.0.0.1'],
     }[param]
 
     self.assertEqual([('127.0.0.1', 9050)], self.controller.get_socks_listeners())
@@ -147,8 +196,8 @@ class TestControl(unittest.TestCase):
     # Again, an old tor, but SocksListenAddress overrides the port number.
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "9050",
-      "SocksListenAddress": ["127.0.0.1:1112"],
+      'SocksPort': '9050',
+      'SocksListenAddress': ['127.0.0.1:1112'],
     }[param]
 
     self.assertEqual([('127.0.0.1', 1112)], self.controller.get_socks_listeners())
@@ -156,8 +205,8 @@ class TestControl(unittest.TestCase):
     # Again, an old tor, but multiple listeners
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "9050",
-      "SocksListenAddress": ["127.0.0.1:1112", "127.0.0.1:1114"],
+      'SocksPort': '9050',
+      'SocksListenAddress': ['127.0.0.1:1112', '127.0.0.1:1114'],
     }[param]
 
     self.assertEqual([('127.0.0.1', 1112), ('127.0.0.1', 1114)], self.controller.get_socks_listeners())
@@ -165,8 +214,8 @@ class TestControl(unittest.TestCase):
     # Again, an old tor, but no SOCKS listeners
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "0",
-      "SocksListenAddress": [],
+      'SocksPort': '0',
+      'SocksListenAddress': [],
     }[param]
 
     self.assertEqual([], self.controller.get_socks_listeners())
@@ -174,22 +223,22 @@ class TestControl(unittest.TestCase):
     # Where tor provides invalid ports or addresses
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "blarg",
-      "SocksListenAddress": ["127.0.0.1"],
+      'SocksPort': 'blarg',
+      'SocksListenAddress': ['127.0.0.1'],
     }[param]
 
     self.assertRaises(stem.ProtocolError, self.controller.get_socks_listeners)
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "0",
-      "SocksListenAddress": ["127.0.0.1:abc"],
+      'SocksPort': '0',
+      'SocksListenAddress': ['127.0.0.1:abc'],
     }[param]
 
     self.assertRaises(stem.ProtocolError, self.controller.get_socks_listeners)
 
     get_conf_mock.side_effect = lambda param, **kwargs: {
-      "SocksPort": "40",
-      "SocksListenAddress": ["500.0.0.1"],
+      'SocksPort': '40',
+      'SocksListenAddress': ['500.0.0.1'],
     }[param]
 
     self.assertRaises(stem.ProtocolError, self.controller.get_socks_listeners)
@@ -253,8 +302,8 @@ class TestControl(unittest.TestCase):
     # get a default value when the call fails
 
     self.assertEqual(
-      "default returned",
-      self.controller.get_protocolinfo(default = "default returned")
+      'default returned',
+      self.controller.get_protocolinfo(default = 'default returned')
     )
 
     # no default value, accept the error
@@ -338,9 +387,9 @@ class TestControl(unittest.TestCase):
 
     # build a single router status entry
 
-    nickname = "Beaver"
-    fingerprint = "/96bKo4soysolMgKn5Hex2nyFSY"
-    desc = "r %s %s u5lTXJKGsLKufRLnSyVqT7TdGYw 2012-12-30 22:02:49 77.223.43.54 9001 0\ns Fast Named Running Stable Valid\nw Bandwidth=75" % (nickname, fingerprint)
+    nickname = 'Beaver'
+    fingerprint = '/96bKo4soysolMgKn5Hex2nyFSY'
+    desc = 'r %s %s u5lTXJKGsLKufRLnSyVqT7TdGYw 2012-12-30 22:02:49 77.223.43.54 9001 0\ns Fast Named Running Stable Valid\nw Bandwidth=75' % (nickname, fingerprint)
     router = stem.descriptor.router_status_entry.RouterStatusEntryV3(desc)
 
     # always return the same router status entry
@@ -368,8 +417,8 @@ class TestControl(unittest.TestCase):
     # get a default value when the call fails
 
     self.assertEqual(
-      "default returned",
-      self.controller.get_network_status(nickname, default = "default returned")
+      'default returned',
+      self.controller.get_network_status(nickname, default = 'default returned')
     )
 
     # no default value, accept the error
@@ -407,12 +456,12 @@ class TestControl(unittest.TestCase):
 
     # get a list of fake, but good looking, streams
     valid_streams = (
-      ("1", "NEW", "4", "10.10.10.1:80"),
-      ("2", "SUCCEEDED", "4", "10.10.10.1:80"),
-      ("3", "SUCCEEDED", "4", "10.10.10.1:80")
+      ('1', 'NEW', '4', '10.10.10.1:80'),
+      ('2', 'SUCCEEDED', '4', '10.10.10.1:80'),
+      ('3', 'SUCCEEDED', '4', '10.10.10.1:80')
     )
 
-    response = "".join(["%s\r\n" % " ".join(entry) for entry in valid_streams])
+    response = ''.join(['%s\r\n' % ' '.join(entry) for entry in valid_streams])
 
     with patch('stem.control.Controller.get_info', Mock(return_value = response)):
       streams = self.controller.get_streams()
@@ -432,7 +481,7 @@ class TestControl(unittest.TestCase):
     # Response when the stream is in a state where it can't be attached (for
     # instance, it's already open).
 
-    response = stem.response.ControlMessage.from_str("555 Connection is not managed by controller.\r\n")
+    response = stem.response.ControlMessage.from_str('555 Connection is not managed by controller.\r\n')
 
     with patch('stem.control.Controller.msg', Mock(return_value = response)):
       self.assertRaises(UnsatisfiableRequest, self.controller.attach_stream, 'stream_id', 'circ_id')
@@ -476,3 +525,16 @@ class TestControl(unittest.TestCase):
 
     for test_input in malformed_inputs:
       self.assertRaises(ProtocolError, _parse_circ_path, test_input)
+
+  @patch('stem.control.Controller.get_version')
+  def test_drop_guards(self, get_version_mock):
+    """
+    Exercises the drop_guards() method.
+    """
+
+    get_version_mock.return_value = stem.version.Version('0.1.0.14')
+    self.assertRaises(UnsatisfiableRequest, self.controller.drop_guards)
+
+    with patch('stem.control.Controller.msg', Mock(return_value = None)):
+      get_version_mock.return_value = stem.version.Version('0.2.5.2')
+      self.controller.drop_guards()
