@@ -18,8 +18,8 @@ class TestExtraInfoDescriptor(unittest.TestCase):
 
     desc = get_relay_extrainfo_descriptor()
 
-    self.assertEquals("ninja", desc.nickname)
-    self.assertEquals("B2289C3EAB83ECD6EB916A2F481A02E6B76A0A48", desc.fingerprint)
+    self.assertEquals('ninja', desc.nickname)
+    self.assertEquals('B2289C3EAB83ECD6EB916A2F481A02E6B76A0A48', desc.fingerprint)
     self.assertTrue(CRYPTO_BLOB in desc.signature)
 
   def test_unrecognized_line(self):
@@ -27,15 +27,15 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     Includes unrecognized content in the descriptor.
     """
 
-    desc = get_relay_extrainfo_descriptor({"pepperjack": "is oh so tasty!"})
-    self.assertEquals(["pepperjack is oh so tasty!"], desc.get_unrecognized_lines())
+    desc = get_relay_extrainfo_descriptor({'pepperjack': 'is oh so tasty!'})
+    self.assertEquals(['pepperjack is oh so tasty!'], desc.get_unrecognized_lines())
 
   def test_proceeding_line(self):
     """
     Includes a line prior to the 'extra-info' entry.
     """
 
-    desc_text = b"exit-streams-opened port=80\n" + get_relay_extrainfo_descriptor(content = True)
+    desc_text = b'exit-streams-opened port=80\n' + get_relay_extrainfo_descriptor(content = True)
     self._expect_invalid_attr(desc_text)
 
   def test_trailing_line(self):
@@ -43,7 +43,7 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     Includes a line after the 'router-signature' entry.
     """
 
-    desc_text = get_relay_extrainfo_descriptor(content = True) + b"\nexit-streams-opened port=80"
+    desc_text = get_relay_extrainfo_descriptor(content = True) + b'\nexit-streams-opened port=80'
     self._expect_invalid_attr(desc_text)
 
   def test_extrainfo_line_missing_fields(self):
@@ -54,15 +54,15 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     """
 
     test_entries = (
-      "ninja",
-      "ninja ",
-      "B2289C3EAB83ECD6EB916A2F481A02E6B76A0A48",
-      " B2289C3EAB83ECD6EB916A2F481A02E6B76A0A48",
+      'ninja',
+      'ninja ',
+      'B2289C3EAB83ECD6EB916A2F481A02E6B76A0A48',
+      ' B2289C3EAB83ECD6EB916A2F481A02E6B76A0A48',
     )
 
     for entry in test_entries:
-      desc_text = get_relay_extrainfo_descriptor({"extra-info": entry}, content = True)
-      desc = self._expect_invalid_attr(desc_text, "nickname")
+      desc_text = get_relay_extrainfo_descriptor({'extra-info': entry}, content = True)
+      desc = self._expect_invalid_attr(desc_text, 'nickname')
       self.assertEquals(None, desc.nickname)
       self.assertEquals(None, desc.fingerprint)
 
@@ -72,27 +72,27 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     invalid data.
     """
 
-    geoip_db_digest = "916A3CA8B7DF61473D5AE5B21711F35F301CE9E8"
-    desc = get_relay_extrainfo_descriptor({"geoip-db-digest": geoip_db_digest})
+    geoip_db_digest = '916A3CA8B7DF61473D5AE5B21711F35F301CE9E8'
+    desc = get_relay_extrainfo_descriptor({'geoip-db-digest': geoip_db_digest})
     self.assertEquals(geoip_db_digest, desc.geoip_db_digest)
 
-    desc = get_relay_extrainfo_descriptor({"geoip6-db-digest": geoip_db_digest})
+    desc = get_relay_extrainfo_descriptor({'geoip6-db-digest': geoip_db_digest})
     self.assertEquals(geoip_db_digest, desc.geoip6_db_digest)
 
     test_entries = (
-      "",
-      "916A3CA8B7DF61473D5AE5B21711F35F301CE9E",
-      "916A3CA8B7DF61473D5AE5B21711F35F301CE9E88",
-      "916A3CA8B7DF61473D5AE5B21711F35F301CE9EG",
-      "916A3CA8B7DF61473D5AE5B21711F35F301CE9E-",
+      '',
+      '916A3CA8B7DF61473D5AE5B21711F35F301CE9E',
+      '916A3CA8B7DF61473D5AE5B21711F35F301CE9E88',
+      '916A3CA8B7DF61473D5AE5B21711F35F301CE9EG',
+      '916A3CA8B7DF61473D5AE5B21711F35F301CE9E-',
     )
 
     for entry in test_entries:
-      desc_text = get_relay_extrainfo_descriptor({"geoip-db-digest": entry}, content = True)
-      self._expect_invalid_attr(desc_text, "geoip_db_digest", entry)
+      desc_text = get_relay_extrainfo_descriptor({'geoip-db-digest': entry}, content = True)
+      self._expect_invalid_attr(desc_text, 'geoip_db_digest', entry)
 
-      desc_text = get_relay_extrainfo_descriptor({"geoip6-db-digest": entry}, content = True)
-      self._expect_invalid_attr(desc_text, "geoip6_db_digest", entry)
+      desc_text = get_relay_extrainfo_descriptor({'geoip6-db-digest': entry}, content = True)
+      self._expect_invalid_attr(desc_text, 'geoip6_db_digest', entry)
 
   def test_cell_circuits_per_decile(self):
     """
@@ -100,24 +100,24 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     """
 
     test_entries = (
-      ("0", 0),
-      ("11", 11),
+      ('0', 0),
+      ('11', 11),
     )
 
-    for entry in ("0", "11", "25"):
-      desc = get_relay_extrainfo_descriptor({"cell-circuits-per-decile": entry})
+    for entry in ('0', '11', '25'):
+      desc = get_relay_extrainfo_descriptor({'cell-circuits-per-decile': entry})
       self.assertEquals(int(entry), desc.cell_circuits_per_decile)
 
     test_entries = (
-      "",
-      " ",
-      "-5",
-      "blarg",
+      '',
+      ' ',
+      '-5',
+      'blarg',
     )
 
     for entry in test_entries:
-      desc_text = get_relay_extrainfo_descriptor({"cell-circuits-per-decile": entry}, content = True)
-      self._expect_invalid_attr(desc_text, "cell_circuits_per_decile")
+      desc_text = get_relay_extrainfo_descriptor({'cell-circuits-per-decile': entry}, content = True)
+      self._expect_invalid_attr(desc_text, 'cell_circuits_per_decile')
 
   def test_dir_response_lines(self):
     """
@@ -125,22 +125,22 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     data.
     """
 
-    for keyword in ("dirreq-v2-resp", "dirreq-v3-resp"):
+    for keyword in ('dirreq-v2-resp', 'dirreq-v3-resp'):
       attr = keyword.replace('-', '_').replace('dirreq', 'dir').replace('resp', 'responses')
-      unknown_attr = attr + "_unknown"
+      unknown_attr = attr + '_unknown'
 
-      test_value = "ok=0,unavailable=0,not-found=984,not-modified=0,something-new=7"
+      test_value = 'ok=0,unavailable=0,not-found=984,not-modified=0,something-new=7'
       desc = get_relay_extrainfo_descriptor({keyword: test_value})
       self.assertEquals(0, getattr(desc, attr)[DirResponse.OK])
       self.assertEquals(0, getattr(desc, attr)[DirResponse.UNAVAILABLE])
       self.assertEquals(984, getattr(desc, attr)[DirResponse.NOT_FOUND])
       self.assertEquals(0, getattr(desc, attr)[DirResponse.NOT_MODIFIED])
-      self.assertEquals(7, getattr(desc, unknown_attr)["something-new"])
+      self.assertEquals(7, getattr(desc, unknown_attr)['something-new'])
 
       test_entries = (
-        "ok=-4",
-        "ok:4",
-        "ok=4.not-found=3",
+        'ok=-4',
+        'ok:4',
+        'ok=4.not-found=3',
       )
 
       for entry in test_entries:
@@ -155,11 +155,11 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     and dirreq-v3-tunneled-dl lines with valid and invalid data.
     """
 
-    for keyword in ("dirreq-v2-direct-dl", "dirreq-v2-direct-dl", "dirreq-v2-tunneled-dl", "dirreq-v2-tunneled-dl"):
+    for keyword in ('dirreq-v2-direct-dl', 'dirreq-v2-direct-dl', 'dirreq-v2-tunneled-dl', 'dirreq-v2-tunneled-dl'):
       attr = keyword.replace('-', '_').replace('dirreq', 'dir')
-      unknown_attr = attr + "_unknown"
+      unknown_attr = attr + '_unknown'
 
-      test_value = "complete=2712,timeout=32,running=4,min=741,d1=14507,d2=22702,q1=28881,d3=38277,d4=73729,md=111455,d6=168231,d7=257218,q3=319833,d8=390507,d9=616301,something-new=11,max=29917857"
+      test_value = 'complete=2712,timeout=32,running=4,min=741,d1=14507,d2=22702,q1=28881,d3=38277,d4=73729,md=111455,d6=168231,d7=257218,q3=319833,d8=390507,d9=616301,something-new=11,max=29917857'
       desc = get_relay_extrainfo_descriptor({keyword: test_value})
       self.assertEquals(2712, getattr(desc, attr)[DirStat.COMPLETE])
       self.assertEquals(32, getattr(desc, attr)[DirStat.TIMEOUT])
@@ -177,12 +177,12 @@ class TestExtraInfoDescriptor(unittest.TestCase):
       self.assertEquals(390507, getattr(desc, attr)[DirStat.D8])
       self.assertEquals(616301, getattr(desc, attr)[DirStat.D9])
       self.assertEquals(29917857, getattr(desc, attr)[DirStat.MAX])
-      self.assertEquals(11, getattr(desc, unknown_attr)["something-new"])
+      self.assertEquals(11, getattr(desc, unknown_attr)['something-new'])
 
       test_entries = (
-        "complete=-4",
-        "complete:4",
-        "complete=4.timeout=3",
+        'complete=-4',
+        'complete:4',
+        'complete=4.timeout=3',
       )
 
       for entry in test_entries:
@@ -196,7 +196,7 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     Parses the conn-bi-direct line with valid and invalid data.
     """
 
-    desc = get_relay_extrainfo_descriptor({"conn-bi-direct": "2012-05-03 12:07:50 (500 s) 277431,12089,0,2134"})
+    desc = get_relay_extrainfo_descriptor({'conn-bi-direct': '2012-05-03 12:07:50 (500 s) 277431,12089,0,2134'})
     self.assertEquals(datetime.datetime(2012, 5, 3, 12, 7, 50), desc.conn_bi_direct_end)
     self.assertEquals(500, desc.conn_bi_direct_interval)
     self.assertEquals(277431, desc.conn_bi_direct_below)
@@ -205,21 +205,21 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     self.assertEquals(2134, desc.conn_bi_direct_both)
 
     test_entries = (
-      "",
-      "2012-05-03 ",
-      "2012-05-03",
-      "2012-05-03 12:07:60 (500 s)",
-      "2012-05-03 12:07:50 (500s)",
-      "2012-05-03 12:07:50 (500 s",
-      "2012-05-03 12:07:50 (500 )",
-      "2012-05-03 12:07:50 (500 s)11",
-      "2012-05-03 12:07:50 (500 s) 277431,12089,0",
-      "2012-05-03 12:07:50 (500 s) 277431,12089,0a,2134",
-      "2012-05-03 12:07:50 (500 s) -277431,12089,0,2134",
+      '',
+      '2012-05-03 ',
+      '2012-05-03',
+      '2012-05-03 12:07:60 (500 s)',
+      '2012-05-03 12:07:50 (500s)',
+      '2012-05-03 12:07:50 (500 s',
+      '2012-05-03 12:07:50 (500 )',
+      '2012-05-03 12:07:50 (500 s)11',
+      '2012-05-03 12:07:50 (500 s) 277431,12089,0',
+      '2012-05-03 12:07:50 (500 s) 277431,12089,0a,2134',
+      '2012-05-03 12:07:50 (500 s) -277431,12089,0,2134',
     )
 
     for entry in test_entries:
-      desc_text = get_relay_extrainfo_descriptor({"conn-bi-direct": entry}, content = True)
+      desc_text = get_relay_extrainfo_descriptor({'conn-bi-direct': entry}, content = True)
       desc = self._expect_invalid_attr(desc_text)
       self.assertEquals(None, desc.conn_bi_direct_end)
       self.assertEquals(None, desc.conn_bi_direct_interval)
@@ -238,10 +238,10 @@ class TestExtraInfoDescriptor(unittest.TestCase):
       attr = keyword.replace('-', '_').replace('dirreq', 'dir')
 
       test_entries = (
-        ("0.00%", 0.0),
-        ("0.01%", 0.0001),
-        ("50%", 0.5),
-        ("100.0%", 1.0),
+        ('0.00%', 0.0),
+        ('0.01%', 0.0001),
+        ('50%', 0.5),
+        ('100.0%', 1.0),
       )
 
       for test_value, expected_value in test_entries:
@@ -249,10 +249,10 @@ class TestExtraInfoDescriptor(unittest.TestCase):
         self.assertEquals(expected_value, getattr(desc, attr))
 
       test_entries = (
-        ("", None),
-        (" ", None),
-        ("100", None),
-        ("-5%", -0.05),
+        ('', None),
+        (' ', None),
+        ('100', None),
+        ('-5%', -0.05),
       )
 
       for entry, expected in test_entries:
@@ -269,10 +269,10 @@ class TestExtraInfoDescriptor(unittest.TestCase):
       attr = keyword.replace('-', '_')
 
       test_entries = (
-        ("", []),
-        (" ", []),
-        ("0,0,0", [0.0, 0.0, 0.0]),
-        ("2.3,-4.6,8.9,16.12,32.15", [2.3, -4.6, 8.9, 16.12, 32.15]),
+        ('', []),
+        (' ', []),
+        ('0,0,0', [0.0, 0.0, 0.0]),
+        ('2.3,-4.6,8.9,16.12,32.15', [2.3, -4.6, 8.9, 16.12, 32.15]),
       )
 
       for test_value, expected_value in test_entries:
@@ -280,9 +280,9 @@ class TestExtraInfoDescriptor(unittest.TestCase):
         self.assertEquals(expected_value, getattr(desc, attr))
 
       test_entries = (
-        (",,11", [11.0]),
-        ("abc,5.7,def", [5.7]),
-        ("blarg", []),
+        (',,11', [11.0]),
+        ('abc,5.7,def', [5.7]),
+        ('blarg', []),
       )
 
       for entry, expected in test_entries:
@@ -298,14 +298,14 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     for keyword in ('published', 'geoip-start-time'):
       attr = keyword.replace('-', '_')
 
-      desc = get_relay_extrainfo_descriptor({keyword: "2012-05-03 12:07:50"})
+      desc = get_relay_extrainfo_descriptor({keyword: '2012-05-03 12:07:50'})
       self.assertEquals(datetime.datetime(2012, 5, 3, 12, 7, 50), getattr(desc, attr))
 
       test_entries = (
-        "",
-        "2012-05-03 12:07:60",
-        "2012-05-03 ",
-        "2012-05-03",
+        '',
+        '2012-05-03 12:07:60',
+        '2012-05-03 ',
+        '2012-05-03',
       )
 
       for entry in test_entries:
@@ -320,20 +320,20 @@ class TestExtraInfoDescriptor(unittest.TestCase):
 
     for keyword in ('cell-stats-end', 'entry-stats-end', 'exit-stats-end', 'bridge-stats-end', 'dirreq-stats-end'):
       end_attr = keyword.replace('-', '_').replace('dirreq', 'dir')
-      interval_attr = end_attr[:-4] + "_interval"
+      interval_attr = end_attr[:-4] + '_interval'
 
-      desc = get_relay_extrainfo_descriptor({keyword: "2012-05-03 12:07:50 (500 s)"})
+      desc = get_relay_extrainfo_descriptor({keyword: '2012-05-03 12:07:50 (500 s)'})
       self.assertEquals(datetime.datetime(2012, 5, 3, 12, 7, 50), getattr(desc, end_attr))
       self.assertEquals(500, getattr(desc, interval_attr))
 
       test_entries = (
-        "",
-        "2012-05-03 ",
-        "2012-05-03",
-        "2012-05-03 12:07:60 (500 s)",
-        "2012-05-03 12:07:50 (500s)",
-        "2012-05-03 12:07:50 (500 s",
-        "2012-05-03 12:07:50 (500 )",
+        '',
+        '2012-05-03 ',
+        '2012-05-03',
+        '2012-05-03 12:07:60 (500 s)',
+        '2012-05-03 12:07:50 (500s)',
+        '2012-05-03 12:07:50 (500 s',
+        '2012-05-03 12:07:50 (500 )',
       )
 
       for entry in test_entries:
@@ -350,31 +350,31 @@ class TestExtraInfoDescriptor(unittest.TestCase):
 
     for keyword in ('read-history', 'write-history', 'dirreq-read-history', 'dirreq-write-history'):
       base_attr = keyword.replace('-', '_').replace('dirreq', 'dir')
-      end_attr = base_attr + "_end"
-      interval_attr = base_attr + "_interval"
-      values_attr = base_attr + "_values"
+      end_attr = base_attr + '_end'
+      interval_attr = base_attr + '_interval'
+      values_attr = base_attr + '_values'
 
       test_entries = (
-        ("", []),
-        (" ", []),
-        (" 50,11,5", [50, 11, 5]),
+        ('', []),
+        (' ', []),
+        (' 50,11,5', [50, 11, 5]),
       )
 
       for test_values, expected_values in test_entries:
-        desc = get_relay_extrainfo_descriptor({keyword: "2012-05-03 12:07:50 (500 s)%s" % test_values})
+        desc = get_relay_extrainfo_descriptor({keyword: '2012-05-03 12:07:50 (500 s)%s' % test_values})
         self.assertEquals(datetime.datetime(2012, 5, 3, 12, 7, 50), getattr(desc, end_attr))
         self.assertEquals(500, getattr(desc, interval_attr))
         self.assertEquals(expected_values, getattr(desc, values_attr))
 
       test_entries = (
-        "",
-        "2012-05-03 ",
-        "2012-05-03",
-        "2012-05-03 12:07:60 (500 s)",
-        "2012-05-03 12:07:50 (500s)",
-        "2012-05-03 12:07:50 (500 s",
-        "2012-05-03 12:07:50 (500 )",
-        "2012-05-03 12:07:50 (500 s)11",
+        '',
+        '2012-05-03 ',
+        '2012-05-03',
+        '2012-05-03 12:07:60 (500 s)',
+        '2012-05-03 12:07:50 (500s)',
+        '2012-05-03 12:07:50 (500 s',
+        '2012-05-03 12:07:50 (500 )',
+        '2012-05-03 12:07:50 (500 s)11',
       )
 
       for entry in test_entries:
@@ -394,9 +394,9 @@ class TestExtraInfoDescriptor(unittest.TestCase):
       attr = keyword.replace('-', '_')
 
       test_entries = (
-        ("", {}),
-        ("443=100,other=111", {443: 100, 'other': 111}),
-        ("80=115533759,443=1777,995=690", {80: 115533759, 443: 1777, 995: 690}),
+        ('', {}),
+        ('443=100,other=111', {443: 100, 'other': 111}),
+        ('80=115533759,443=1777,995=690', {80: 115533759, 443: 1777, 995: 690}),
       )
 
       for test_value, expected_value in test_entries:
@@ -404,12 +404,12 @@ class TestExtraInfoDescriptor(unittest.TestCase):
         self.assertEquals(expected_value, getattr(desc, attr))
 
       test_entries = (
-        "8000000=115533759",
-        "-80=115533759",
-        "80=-115533759",
-        "=115533759",
-        "80=",
-        "80,115533759",
+        '8000000=115533759',
+        '-80=115533759',
+        '80=-115533759',
+        '=115533759',
+        '80=',
+        '80,115533759',
       )
 
       for entry in test_entries:
@@ -426,8 +426,8 @@ class TestExtraInfoDescriptor(unittest.TestCase):
       attr = keyword.replace('-', '_').replace('dirreq', 'dir').replace('reqs', 'requests')
 
       test_entries = (
-        ("", {}),
-        ("uk=5,de=3,jp=2", {'uk': 5, 'de': 3, 'jp': 2}),
+        ('', {}),
+        ('uk=5,de=3,jp=2', {'uk': 5, 'de': 3, 'jp': 2}),
       )
 
       for test_value, expected_value in test_entries:
@@ -435,10 +435,10 @@ class TestExtraInfoDescriptor(unittest.TestCase):
         self.assertEquals(expected_value, getattr(desc, attr))
 
       test_entries = (
-        "uk=-4",
-        "uki=4",
-        "uk:4",
-        "uk=4.de=3",
+        'uk=-4',
+        'uki=4',
+        'uk:4',
+        'uk=4.de=3',
       )
 
       for entry in test_entries:
@@ -452,26 +452,26 @@ class TestExtraInfoDescriptor(unittest.TestCase):
 
     desc = get_bridge_extrainfo_descriptor()
 
-    self.assertEquals("ec2bridgereaac65a3", desc.nickname)
-    self.assertEquals("1EC248422B57D9C0BD751892FE787585407479A4", desc.fingerprint)
-    self.assertEquals("006FD96BA35E7785A6A3B8B75FE2E2435A13BDB4", desc.digest())
+    self.assertEquals('ec2bridgereaac65a3', desc.nickname)
+    self.assertEquals('1EC248422B57D9C0BD751892FE787585407479A4', desc.fingerprint)
+    self.assertEquals('006FD96BA35E7785A6A3B8B75FE2E2435A13BDB4', desc.digest())
     self.assertEquals([], desc.get_unrecognized_lines())
 
     # check that we don't have crypto fields
-    self.assertRaises(AttributeError, getattr, desc, "signature")
+    self.assertRaises(AttributeError, getattr, desc, 'signature')
 
   def test_bridge_ip_versions_line(self):
     """
     Parses the 'bridge-ip-versions' line, which only appears in bridges.
     """
 
-    desc = get_bridge_extrainfo_descriptor({"bridge-ip-versions": "v4=16,v6=40"})
+    desc = get_bridge_extrainfo_descriptor({'bridge-ip-versions': 'v4=16,v6=40'})
     self.assertEquals({'v4': 16, 'v6': 40}, desc.ip_versions)
 
-    desc = get_bridge_extrainfo_descriptor({"bridge-ip-versions": ""})
+    desc = get_bridge_extrainfo_descriptor({'bridge-ip-versions': ''})
     self.assertEquals({}, desc.ip_versions)
 
-    desc_text = get_bridge_extrainfo_descriptor({"bridge-ip-versions": "v4=24.5"}, content = True)
+    desc_text = get_bridge_extrainfo_descriptor({'bridge-ip-versions': 'v4=24.5'}, content = True)
     self.assertRaises(ValueError, RelayExtraInfoDescriptor, desc_text)
 
   def test_bridge_ip_transports_line(self):
@@ -479,13 +479,13 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     Parses the 'bridge-ip-transports' line, which only appears in bridges.
     """
 
-    desc = get_bridge_extrainfo_descriptor({"bridge-ip-transports": "<OR>=16,<??>=40"})
+    desc = get_bridge_extrainfo_descriptor({'bridge-ip-transports': '<OR>=16,<??>=40'})
     self.assertEquals({'<OR>': 16, '<??>': 40}, desc.ip_transports)
 
-    desc = get_bridge_extrainfo_descriptor({"bridge-ip-transports": ""})
+    desc = get_bridge_extrainfo_descriptor({'bridge-ip-transports': ''})
     self.assertEquals({}, desc.ip_transports)
 
-    desc_text = get_bridge_extrainfo_descriptor({"bridge-ip-transports": "<OR>=24.5"}, content = True)
+    desc_text = get_bridge_extrainfo_descriptor({'bridge-ip-transports': '<OR>=24.5'}, content = True)
     self.assertRaises(ValueError, RelayExtraInfoDescriptor, desc_text)
 
   def test_transport_line(self):
@@ -493,17 +493,17 @@ class TestExtraInfoDescriptor(unittest.TestCase):
     Basic exercise for both a bridge and relay's transport entry.
     """
 
-    desc = get_bridge_extrainfo_descriptor({"transport": "obfs3"})
-    self.assertEquals({"obfs3": (None, None, None)}, desc.transport)
+    desc = get_bridge_extrainfo_descriptor({'transport': 'obfs3'})
+    self.assertEquals({'obfs3': (None, None, None)}, desc.transport)
     self.assertEquals([], desc.get_unrecognized_lines())
 
-    desc = get_relay_extrainfo_descriptor({"transport": "obfs2 83.212.96.201:33570"})
-    self.assertEquals({"obfs2": ("83.212.96.201", 33570, [])}, desc.transport)
+    desc = get_relay_extrainfo_descriptor({'transport': 'obfs2 83.212.96.201:33570'})
+    self.assertEquals({'obfs2': ('83.212.96.201', 33570, [])}, desc.transport)
     self.assertEquals([], desc.get_unrecognized_lines())
 
     # multiple transport lines
-    desc = get_bridge_extrainfo_descriptor({"transport": "obfs3\ntransport obfs4"})
-    self.assertEquals({"obfs3": (None, None, None), "obfs4": (None, None, None)}, desc.transport)
+    desc = get_bridge_extrainfo_descriptor({'transport': 'obfs3\ntransport obfs4'})
+    self.assertEquals({'obfs3': (None, None, None), 'obfs4': (None, None, None)}, desc.transport)
     self.assertEquals([], desc.get_unrecognized_lines())
 
   def _expect_invalid_attr(self, desc_text, attr = None, expected_value = None):
@@ -523,6 +523,6 @@ class TestExtraInfoDescriptor(unittest.TestCase):
       self.assertEquals(expected_value, getattr(desc, attr))
     else:
       # check a default attribute
-      self.assertEquals("ninja", desc.nickname)
+      self.assertEquals('ninja', desc.nickname)
 
     return desc
