@@ -13,13 +13,13 @@ class TestEnum(unittest.TestCase):
     Checks that the pydoc examples are accurate.
     """
 
-    insects = stem.util.enum.Enum("ANT", "WASP", "LADYBUG", "FIREFLY")
-    self.assertEquals("Ant", insects.ANT)
-    self.assertEquals(("Ant", "Wasp", "Ladybug", "Firefly"), tuple(insects))
+    insects = stem.util.enum.Enum('ANT', 'WASP', 'LADYBUG', 'FIREFLY')
+    self.assertEquals('Ant', insects.ANT)
+    self.assertEquals(('Ant', 'Wasp', 'Ladybug', 'Firefly'), tuple(insects))
 
-    pets = stem.util.enum.Enum(("DOG", "Skippy"), "CAT", ("FISH", "Nemo"))
-    self.assertEquals("Skippy", pets.DOG)
-    self.assertEquals("Cat", pets.CAT)
+    pets = stem.util.enum.Enum(('DOG', 'Skippy'), 'CAT', ('FISH', 'Nemo'))
+    self.assertEquals('Skippy', pets.DOG)
+    self.assertEquals('Cat', pets.CAT)
 
   def test_uppercase_enum_example(self):
     """
@@ -27,15 +27,15 @@ class TestEnum(unittest.TestCase):
     accurate.
     """
 
-    runlevels = stem.util.enum.UppercaseEnum("DEBUG", "INFO", "NOTICE", "WARN", "ERROR")
-    self.assertEquals("DEBUG", runlevels.DEBUG)
+    runlevels = stem.util.enum.UppercaseEnum('DEBUG', 'INFO', 'NOTICE', 'WARN', 'ERROR')
+    self.assertEquals('DEBUG', runlevels.DEBUG)
 
   def test_enum_methods(self):
     """
     Exercises enumeration methods.
     """
 
-    insects = stem.util.enum.Enum("ANT", "WASP", "LADYBUG", "FIREFLY")
+    insects = stem.util.enum.Enum('ANT', 'WASP', 'LADYBUG', 'FIREFLY')
 
     # next method
     self.assertEquals(insects.WASP, insects.next(insects.ANT))
@@ -46,4 +46,4 @@ class TestEnum(unittest.TestCase):
     self.assertEquals(insects.LADYBUG, insects.previous(insects.FIREFLY))
 
     # keys method
-    self.assertEquals(["ANT", "WASP", "LADYBUG", "FIREFLY"], insects.keys())
+    self.assertEquals(['ANT', 'WASP', 'LADYBUG', 'FIREFLY'], insects.keys())
